clear all
cap log close
set more off

global datafile "C:\Users\Usuario\Dropbox\JHR\replication file\datafiles\"
global logfile  "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\"

log using "${logfile}\FigureA1 Distribution_patience_cdf.log", replace

use "${datafile}\Students", clear

***COMMENT 1: Test Scores and Saving Decisions

drop if stratum==14|stratum==15 /*The sample excludes one stratum that mixes 1 public and 2 non-public centers. 
								That stratum originally grouped high schools who intended to teach the course
								to 7th or 8th graders (ESO1 or ESO2).*/

keep if madrid2==1

keep if june_balanced_sample==1

bys COD_CENTRO: gen nalumnos=_n
count if nalumnos==1
count

** PACIENCIA **

* Hypothetical saving choices

** H1 (100 today, 120 in three weeks) 
set seed 999
gen u = uniform()

replace dec100_120=0 if december_CA_P11A==3 & u>=0.5
replace dec100_120=1 if december_CA_P11A==3 & u<0.5
label define dec100_120 1 "100 euros today" 0 "120 in three weeks", replace

replace dec100_120_mis=0 if december_CA_P11A==3		//now, dec100_120_mis=1 only when december_CA_P11A==.
replace dec100_120=0 if dec100_120_mis==1

label define mar100_120 1 "100 euros today" 0 "120 in three weeks", replace

** H2 (100 today, 120 in six weeks) (March)
label define mar100_120_2 1 "100 euros today" 0 "120 in six weeks", replace

** H3 (100 today, 150 in three weeks) 
replace dec100_150=0 if december_CA_P11B==3 & u>=0.5
replace dec100_150=1 if december_CA_P11B==3 & u<0.5
label define dec100_150 1 "100 euros today" 0 "150 in three weeks", replace

replace dec100_150_mis=0 if december_CA_P11B==3		//now, dec100_150_mis=1 only when december_CA_P11B==.
replace dec100_150=0 if dec100_150_mis==1

label define mar100_150 1 "100 euros today" 0 "150 in three weeks", replace

** H4 (100 today, 180 in three weeks) 
replace dec100_180=0 if december_CA_P11C==3 & u>=0.5
replace dec100_180=1 if december_CA_P11C==3 & u<0.5
label define dec100_180 1 "100 euros today" 0 "180 in three weeks", replace

replace dec100_180_mis=0 if december_CA_P11C==3		//now, dec100_180_mis=1 only when december_CA_P11C==.
replace dec100_180=0 if dec100_180_mis==1

label define mar100_180 1 "100 euros today" 0 "180 in three weeks", replace


* Inconsistent choices
gen 	dC0dRpos2 =0
replace dC0dRpos2 =1 if (juego1<juego2)
gen 	dC0dRpos3 =0
replace dC0dRpos3 =1 if (juego2<juego3) | (juego1<juego3)
gen 	dC0dRpos5 =0
replace dC0dRpos5 =1 if (juego4<juego5)
gen 	dC0dRpos6 =0
replace dC0dRpos6 =1 if (juego5<juego6) | (juego4<juego6)
gen 	dC0dRpos8 =0
replace dC0dRpos8 =1 if (juego7<juego8)
gen 	dC0dRpos9 =0
replace dC0dRpos9 =1 if (juego8<juego9) | (juego7<juego9)

gen 	dC0dRposE2 =0
replace dC0dRposE2 =1 if dC0dRpos2==1 
gen 	dC0dRposE3 =0
replace dC0dRposE3 =1 if dC0dRpos3==1
gen 	dC0dRposE5 =0
replace dC0dRposE5 =1 if dC0dRpos3==1|(juego5<juego2)
gen 	dC0dRposE6 =0
replace dC0dRposE6 =1 if dC0dRpos6==1|(juego6<juego3)
gen 	dC0dRposE8 =0
replace dC0dRposE8 =1 if dC0dRpos8==1
gen 	dC0dRposE9 =0
replace dC0dRposE9 =1 if dC0dRpos9==1

* Vertical form (Each observation is one student-game)
reshape long J dC0dRpos dC0dRposE, i(idestu) j(game)

* Experiments involving current expenditure
gen		immed=0
replace immed=1 if game==2|game==3|game==5|game==6

* Interest rate
gen		R=0
replace R=1 if game==2 | game==5 | game==8
replace R=2 if game==3 | game==6 | game==9

* Delay
gen		delay=1 if game ==2 | game== 3 | game==8 | game==9
replace delay=2 if game ==5 | game==6
gen 	delay_R=R*delay

* Treatment variables
gen	treatment=(curso==3)
gen	Janschool=(treated==1)	

gen Jtreat=Janschool*treatment
gen Jtreat_imme  = immed*Jtreat
gen Jtreat_delay = delay*Jtreat
gen Jtreat_R	 = R*Jtreat

gen Atreat=(1-Janschool)*treatment
gen Atreat_imme  = immed*Atreat
gen Atreat_delay = delay*Atreat
gen Atreat_R	 = R*Atreat

gen Otreat=treatment
gen Otreat_imme  = immed*Otreat
gen Otreat_delay = delay*Otreat
gen Otreat_R	 = R*Otreat

egen cluster_cole=group(COD_CENTRO curso)

* EUR allocated to earlier date
gen		euro_soon=juego2 if game==2
replace euro_soon=juego3 if game==3
replace euro_soon=juego5 if game==5
replace euro_soon=juego6 if game==6
replace euro_soon=juego8 if game==8
replace euro_soon=juego9 if game==9

gen		game2=0
replace game2=1 if game==2

gen		game3=0
replace game3=1 if game==3

gen		game5=0
replace game5=1 if game==5

gen		game6=0
replace game6=1 if game==6

gen		game8=0
replace game8=1 if game==8

gen		game9=0
replace game9=1 if game==9

drop if game==1|game==4|game==7

label variable treated 		"Treated"
label variable immed 		"Immediate payment"
label variable R 			"Interest rate"
label variable delay		"Delay"
label variable dec100_120 	"Prefers 100 euro today to 120 in 3 weeks (Dec)"
label variable dec100_150 	"Prefers 100 euro today to 150 in 3 weeks (Dec)"
label variable dec100_180 	"Prefers 100 euro today to 180 in 3 weeks (Dec)"

global dec_hypothetical dec100_120 dec100_150 dec100_180 
global stratum stratum_c2 stratum_c3 stratum_c7

gen Otreat_public=publico2*Otreat


mat euro_soon=J(3,4,0)
mat norm_test=J(3,4,0)

replace stratum_c2=1 if stratum_c3==1

reg euro_soon Jtreat immed R delay stratum_c2 stratum_c7  if Jtreat==1|curso==4, r cluster(cluster_cole)

reg euro_soon Jtreat immed R delay stratum_c2 stratum_c7 $dec_hypothetical if Jtreat==1|curso==4, r cluster(cluster_cole)

* Public

gen share_soon=euro_soon/6

tab share_soon


*** 2. 3. 4. Fraction with less than 25%, 35%, 50% questions correct (d25, d35, d50)

preserve

gen n=_n
gen index=(n/6)
gen cdfT=.
gen cdfC=.
qui compress
local i=1
while `i'<=6 {
	gen d`i'=(share_soon<=((`i'/6))) 
	sum d`i'
	reg d`i' Jtreat immed R delay stratum_c2 stratum_c7 if (Jtreat==1|curso==4), cluster(COD_CENTRO)
	replace cdfT=_b[_cons] + _b[Jtreat] if _n==`i'
	replace cdfC=_b[_cons] if _n==`i'
	drop d`i'
	qui compress
local i=`i'+1
}


keep if cdfT!=.
keep n index cdf*
drop if index>7
sort n
sc cdfT cdfC index, graphregion(fcolor(white)) c(l l) title("Cumulative distribution function of earlier choice") xtitle("Fraction of euros allocated to earlier date") /*
*/ ytitle("Cumulative percentage of the sample") msymbol(i i) lwidth(thick thick) lcolor(black gray) lpattern(solid shortdash) /*
*/legend(label(1 "Treated") label(2 "Control") rows(2)) 

restore

*********** NON-PUBLIC SCHOOLS

gen n=_n
gen index=(n/6)
gen cdfT=.
gen cdfC=.
qui compress
local i=1
while `i'<=6 {
	gen d`i'=(share_soon<=((`i'/6))) 
	sum d`i'
	reg d`i' Jtreat immed R delay stratum_c2 stratum_c7 if (Jtreat==1|curso==4) & publico2==0, cluster(COD_CENTRO)
	replace cdfT=_b[_cons] + _b[Jtreat] if _n==`i'
	replace cdfC=_b[_cons] if _n==`i'
	drop d`i'
	qui compress
local i=`i'+1
}

preserve

keep if cdfT!=.
keep n index cdf*
drop if index>7
sort n
sc cdfT cdfC index, c(l l)  xtitle("Fraction of euros allocated to earlier date, non-public") /*
*/ ytitle("Cumulative percentage of the sample")  ylabel(.5 .6 .7 .8 .9 1) msymbol(i i) lwidth(thick thick) lcolor(black gray) lpattern(solid shortdash) /*
*/legend(label(1 "Treated") label(2 "Control") rows(2)) graphregion(fcolor(white))

graph save Graph "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\FigureA1_Patience_cdf_non-public.gph",replace
graph export "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\FigureA1_Patience_cdf_non-public.pdf",replace

*********** PUBLIC SCHOOLS
restore

drop n index cdf* 

gen n=_n
gen index=(n/6)
gen cdfT=.
gen cdfC=.
qui compress
local i=1
while `i'<=6 {
	gen d`i'=(share_soon<=((`i'/6))) 
	sum d`i'
	reg d`i' Jtreat immed R delay stratum_c2 stratum_c7 if (Jtreat==1|curso==4) & publico2==1, cluster(COD_CENTRO)
	replace cdfT=_b[_cons] + _b[Jtreat] if _n==`i'
	replace cdfC=_b[_cons] if _n==`i'
	drop d`i'
	qui compress
local i=`i'+1
}


keep if cdfT!=.
keep n index cdf*
drop if index>7
sort n
sc cdfT cdfC index, c(l l) xtitle("Fraction of euros allocated to earlier date, public") /*
*/ ytitle("Cumulative percentage of the sample") msymbol(i i) ylabel(.5 .6 .7 .8 .9 1) lwidth(thick thick) lcolor(black gray) lpattern(solid shortdash) /*
*/legend(label(1 "Treated") label(2 "Control") rows(2)) graphregion(fcolor(white))

graph save Graph "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\FigureA1_Patience_cdf_public.gph",replace

gr combine "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\FigureA1_Patience_cdf_public.gph" "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\FigureA1_Patience_cdf_non-public.gph",graphregion(fcolor(white))

graph export "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\FigureA1_Patience_cdf.pdf",replace

cap log close
