*File Name: Experimento // CTB_horizontal_may2023
*This version: April 2016 // May 2023
*Authors: Laura Hospido (laura.hospido@bde.es) - Ernesto Villanueva
*--------------------------------------------------------------------------
* Please notify and cite the authors to distribute and/or modify this work.
*--------------------------------------------------------------------------
set more off
clear all
cap log close


global datos_junio "C:\Users\Usuario\Dropbox\JHR\replication file\datafiles"
global logfiles "C:\Users\Usuario\Dropbox\JHR\replication file\Figures\FigureA2\logfiles\"
global graphfiles "C:\Users\Usuario\Dropbox\JHR\replication file\graphfiles\test"
global graphfiles_repl "C:\Users\Usuario\Dropbox\JHR\replication file\Figures\FigureA2\Figures"



log using "${logfiles}\FigureA2.log", replace

**********************************************************************************
********************************* UNBALANCED SAMPLE ******************************
**********************************************************************************

******************
**** BALANCED ****
******************

use "${datos_junio}\Students", clear


*** MADRID ONLY  ***

keep if stratum_c == 1|  stratum_c == 2 | stratum_c == 3 | (stratum_c==7)
drop publico
qui compress

qui compress

set more off


gen		treatment=1 if curso==3
replace treatment=0 if curso==4
egen cluster_cole=group(COD_CENTRO curso)

replace stratum_c11=1 if stratum_c12==1
drop stratum_c12 stratum_c

gen 	b100_120=(december_CA_P11A==1)
replace b100_120=. if (december_CA_P11A==3|december_CA_P11A==.)
drop if b100_120==.

gen 	b100_150=(december_CA_P11B==1)
replace b100_150=. if (december_CA_P11B==3|december_CA_P11B==.)
drop if b100_150==.

gen 	b100_180=(december_CA_P11C==1)
replace b100_180=. if (december_CA_P11C==3|december_CA_P11C==.)
drop if b100_180==.



/* ********************* HYPOTHETICAL CHOICES ******************* */

gen 	early_treated=1 if (treatment==1& treated==1)
replace early_treated=2 if (treatment==0)
replace early_treated=3 if (treatment==1& treated==0)

drop if early_treated==3

*Early treated, public

foreach x in b100_120 b100_150 b100_180{
	
	reg `x' if early_treated==1 & public==1, cluster(cluster_cole)
	gen `x'_3_early=_b[_cons] if early_treated==1 & public==1
	mat A=get(VCE)
	gen sd_`x'_3_early=A[1,1]^.5 if early_treated==1 & public==1

	gen l_`x'_3_early=`x'_3_early-1.96*sd_`x'_3_early if early_treated==1 & public==1
	gen u_`x'_3_early=`x'_3_early+1.96*sd_`x'_3_early if early_treated==1 & public==1

*Controls

	reg `x' if early_treated==2 & public==1, cluster(cluster_cole) 
	replace `x'_3_early=_b[_cons] if early_treated==2 & public==1
	mat A=get(VCE)
	replace sd_`x'_3_early=A[1,1]^.5 if early_treated==2 & public==1

	replace l_`x'_3_early=`x'_3_early-1.96*sd_`x'_3_early if early_treated==2 & public==1
	replace u_`x'_3_early=`x'_3_early+1.96*sd_`x'_3_early if early_treated==2 & public==1
	
}

***100 vs 120

graph twoway (bar b100_120_3_early early_treated if early_treated==1 & public==1, fcolor(white)) /// 
(bar b100_120_3_early early_treated if early_treated==2 & public==1, fcolor(gray)) /// 
(rcap l_b100_120_3_early u_b100_120_3_early early_treated), ylabel(0(0.1)0.3) ///
legend(row(1) order (1 "Treat" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("100 euros today vs 120 in 3 weeks" ) graphregion(fcolor(white))

graph save Graph "${logfiles}\100vs120_public.gph", replace

***100 vs 150

graph twoway (bar b100_150_3_early early_treated if early_treated==1 & public==1, fcolor(white)) /// 
(bar b100_150_3_early early_treated if early_treated==2 & public==1, fcolor(gray)) /// 
(rcap l_b100_150_3_early u_b100_150_3_early early_treated), ylabel(0(0.1)0.3) ///
legend(row(1) order (1 "Treat" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("100 euros today vs 150 in 3 weeks" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\100vs150_public.gph", replace

***100 vs 180

graph twoway (bar b100_180_3_early early_treated if early_treated==1 & public==1, fcolor(white)) /// 
(bar b100_180_3_early early_treated if early_treated==2 & public==1,fcolor(gray)) /// 
(rcap l_b100_180_3_early u_b100_180_3_early early_treated), ylabel(0(0.1)0.3) ///
legend(row(1) order (1 "Treat" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("100 euros today vs 180 in 3 weeks" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\100vs180_public.gph", replace

gr combine "${logfiles}\100vs120_public.gph" "${logfiles}\100vs150_public.gph" "${logfiles}\100vs180_public.gph", /*
*/ col(3) ycommon title("Hypothetical choices at baseline, public") subtitle("Early Treated (9th graders) vs Control (10th graders)") graphregion(fcolor(white))


graph save Graph "${logfiles}\hypoth_early_public.gph", replace

graph export "${logfiles}\hypoth_early_public.eps", as(eps) replace
graph export "${logfiles}\hypoth_early_public.pdf", as(pdf) replace

erase "${logfiles}\100vs120_public.gph" 
erase "${logfiles}\100vs150_public.gph"
erase "${logfiles}\100vs180_public.gph"




******************************* TREATED IN JANUARY-MARCH ***********************
* Today vs. One week *

* R=1
reg juego2 treatment stratum_c7 b100_120  b100_150 b100_180 if (treatment==0 | (treatment==1& treated==1)), robust cluster(cluster_cole)

* R=1.5 
reg juego3 treatment stratum_c7 b100_120  b100_150 b100_180 if (treatment==0 | (treatment==1& treated==1)), robust cluster(cluster_cole)

* Today vs. Two weeks *

* R=1
reg juego5 treatment stratum_c7 b100_120  b100_150 b100_180 if (treatment==0 | (treatment==1& treated==1)), robust cluster(cluster_cole)

* R=1.5

reg juego6 treatment stratum_c7 b100_120  b100_150 b100_180 if (treatment==0 | (treatment==1& treated==1)), robust cluster(cluster_cole)

* One week vs. Two weeks *
* R=1

reg juego8 treatment stratum_c7 b100_120  b100_150 b100_180 if (treatment==0 | (treatment==1& treated==1)), robust cluster(cluster_cole)

* R=1.5
reg juego9 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (treatment==0 | (treatment==1& treated==1)), robust cluster(cluster_cole)

/* TREATMENT GRAPH */


*Early treated, public

foreach x in juego2 juego3 juego5 juego6 juego8 juego9{
	
	reg `x' 							if early_treated==1 & public==1, cluster(cluster_cole)
	gen `x'_3_early_public=_b[_cons] 	if early_treated==1 & public==1
	mat A=get(VCE)
	gen sd_`x'_3_early_public=A[1,1]^.5 if early_treated==1 & public==1

	gen l_`x'_3_early_public=`x'_3_early-1.96*sd_`x'_3_early if early_treated==1 & public==1
	gen u_`x'_3_early_public=`x'_3_early+1.96*sd_`x'_3_early if early_treated==1 & public==1

*Controls

	reg `x' 							 if early_treated==2 & public==1, cluster(cluster_cole)
	replace `x'_3_early_public=_b[_cons] if early_treated==2 & public==1
	mat A=get(VCE)
	replace sd_`x'_3_early_public=A[1,1]^.5 if early_treated==2 & public==1

	replace l_`x'_3_early_public=`x'_3_early-1.96*sd_`x'_3_early if early_treated==2 & public==1
	replace u_`x'_3_early_public=`x'_3_early+1.96*sd_`x'_3_early if early_treated==2 & public==1
	
}

*Early treated, non-public

foreach x in juego2 juego3 juego5 juego6 juego8 juego9{
	
	reg `x' 					  if early_treated==1 & public==0, cluster(cluster_cole)
	gen `x'_3_early_non =_b[_cons] if early_treated==1 & public==0
	mat A=get(VCE)
	gen sd_`x'_3_early_non=A[1,1]^.5 if early_treated==1 & public==0

	gen l_`x'_3_early_non=`x'_3_early_non-1.96*sd_`x'_3_early_non if early_treated==1 & public==0
	gen u_`x'_3_early_non=`x'_3_early_non+1.96*sd_`x'_3_early_non if early_treated==1 & public==0

*Controls

	reg `x' 							if early_treated==2 & public==0, cluster(cluster_cole)
	replace `x'_3_early_non=_b[_cons]   if early_treated==2 & public==0
	mat A=get(VCE)
	replace sd_`x'_3_early_non=A[1,1]^.5 if early_treated==2 & public==0

	replace l_`x'_3_early_non=`x'_3_early_non-1.96*sd_`x'_3_early_non if early_treated==2 & public==0
	replace u_`x'_3_early_non=`x'_3_early_non+1.96*sd_`x'_3_early_non if early_treated==2 & public==0
	
}

/* ********************* OUTCOME IN THE EXPERIMENT *************** */

*********PUBLIC**************
/* ** Today vs one week ** */

graph twoway (bar juego2_3_early_public early_treated if early_treated==1 & public==1, fcolor(white)) ///
(bar juego2_3_early_public early_treated if early_treated==2 & public==1, fcolor(gray)) ///
(rcap l_juego2_3_early_public u_juego2_3_early_public early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "T" 2 "C")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=1" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego2_public.gph", replace

graph twoway (bar juego3_3_early_public early_treated if early_treated==1  & public==1, fcolor(white)) ///
(bar juego3_3_early_public early_treated if early_treated==2  & public==1, fcolor(gray)) ///
(rcap l_juego3_3_early_public u_juego3_3_early_public early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=2 " ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego3_public.gph", replace

gr combine "${logfiles}\juego2_public.gph" "${logfiles}\juego3_public.gph", ycommon title("Public: Today vs. One week") graphregion(fcolor(white))
graph save "${logfiles}\FigureA2PanelA_public.gph", replace
graph use "${logfiles}\FigureA2PanelA_public.gph", scheme(s2mono)
graph save "${logfiles}\FigureA2PanelA_public.gph", replace
graph export "${logfiles}\FigureA2PanelA_public.eps", as(eps) replace
graph export "${logfiles}\FigureA2PanelA_public.pdf", as(pdf) replace

erase "${logfiles}\juego2_public.gph" 
erase "${logfiles}\juego3_public.gph"


*********NON PUBLIC**************
/* ** Today vs one week ** */

graph twoway (bar juego2_3_early_non early_treated if early_treated==1 & public==0, fcolor(white)) ///
(bar juego2_3_early_non early_treated if early_treated==2 & public==0, fcolor(gray)) ///
(rcap l_juego2_3_early_non u_juego2_3_early_non early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=1" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego2_non.gph", replace

graph twoway (bar juego3_3_early_non early_treated if early_treated==1  & public==0, fcolor(white)) ///
(bar juego3_3_early_non early_treated if early_treated==2  & public==0, fcolor(gray)) ///
(rcap l_juego3_3_early_non u_juego3_3_early_non early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=2 " ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego3_non.gph", replace

gr combine "${logfiles}\juego2_non.gph" "${logfiles}\juego3_non.gph", ycommon title("Non-public: Today vs. One week") graphregion(fcolor(white))
graph save "${logfiles}\FigureA2PanelA_non.gph", replace
graph use "${logfiles}\FigureA2PanelA_non.gph", scheme(s2mono)
graph save "${logfiles}\FigureA2PanelA_non.gph", replace
graph export "${logfiles}\FigureA2PanelA_non.eps", as(eps) replace
graph export "${logfiles}\FigureA2PanelA_non.pdf", as(pdf) replace

erase "${logfiles}\juego2_non.gph" 
erase "${logfiles}\juego3_non.gph"


** Today vs two weeks, public

graph twoway (bar juego5_3_early_public early_treated if early_treated==1 & public==1, fcolor(white)) ///
(bar juego5_3_early_public early_treated if early_treated==2 & public==1, fcolor(gray)) ///
(rcap l_juego5_3_early_public u_juego5_3_early_public early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=1" ) graphregion(fcolor(white))

graph save Graph "${logfiles}\juego5_public.gph", replace

graph twoway (bar juego6_3_early_public early_treated if early_treated==1 & public==1, fcolor(white)) ///
(bar juego6_3_early_public early_treated if early_treated==2 & public==1, fcolor(gray)) ///
(rcap l_juego6_3_early_public u_juego6_3_early_public early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=2" ) graphregion(fcolor(white))

graph save Graph "${logfiles}\juego6_public.gph", replace

gr combine "${logfiles}\juego5_public.gph" "${logfiles}\juego6_public.gph", ycommon title("Public: Today vs. Two weeks") graphregion(fcolor(white))

graph save   "${logfiles}\FigureA2PanelB_public.gph", replace
graph use    "${logfiles}\FigureA2PanelB_public.gph", scheme(s2mono)
graph save   "${logfiles}\FigureA2PanelB_public.gph", replace
graph export "${logfiles}\FigureA2PanelB_public.eps", as(eps) replace
graph export "${logfiles}\FigureA2PanelB_public.pdf", as(pdf) replace

erase "${logfiles}\juego5_public.gph" 
erase "${logfiles}\juego6_public.gph"

** Today vs two weeks, non-public

graph twoway (bar juego5_3_early_non early_treated if early_treated==1 & public==0, fcolor(white)) ///
(bar juego5_3_early_non early_treated if early_treated==2 & public==0, fcolor(gray)) ///
(rcap l_juego5_3_early_non u_juego5_3_early_non early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=1" ) graphregion(fcolor(white))

graph save Graph "${logfiles}\juego5_non.gph", replace

graph twoway (bar juego6_3_early_non early_treated if early_treated==1 & public==0, fcolor(white)) ///
(bar juego6_3_early_non early_treated if early_treated==2 & public==0, fcolor(gray)) ///
(rcap l_juego6_3_early_non u_juego6_3_early_non early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=2" ) graphregion(fcolor(white))

graph save Graph "${logfiles}\juego6_non.gph", replace

gr combine "${logfiles}\juego5_non.gph" "${logfiles}\juego6_non.gph", ycommon title("Non-public: Today vs. Two weeks") graphregion(fcolor(white))

graph save   "${logfiles}\FigureA2PanelB_non.gph", replace
graph use   "${logfiles}\FigureA2PanelB_non.gph", scheme(s2mono)
graph save   "${logfiles}\FigureA2PanelB_non.gph", replace
graph export "${logfiles}\FigureA2PanelB_non.eps", as(eps) replace
graph export "${logfiles}\FigureA2PanelB_non.pdf", as(pdf) replace

erase "${logfiles}\juego5_non.gph" 
erase "${logfiles}\juego6_non.gph"


****************************************************
** One vs two weeks, public

graph twoway (bar juego8_3_early_public early_treated if early_treated==1 & public==1, fcolor(white)) ///
(bar juego8_3_early_public early_treated if early_treated==2 & public==1, fcolor(gray)) ///
(rcap l_juego8_3_early_public u_juego8_3_early_public early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=1" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego8_public.gph", replace

graph twoway (bar juego9_3_early_public early_treated if early_treated==1 & public==1, fcolor(white)) ///
(bar juego9_3_early_public early_treated if early_treated==2 & public==1, fcolor(gray)) ///
(rcap l_juego9_3_early_public u_juego9_3_early_public early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=2" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego9_public.gph", replace


gr combine "${logfiles}\juego8_public.gph" "${logfiles}\juego9_public.gph", ycommon title("Public: One week vs. Two weeks") graphregion(fcolor(white))

graph save "${logfiles}\FigureA2PanelC_public.gph", replace
graph use "${logfiles}\FigureA2PanelC_public.gph", scheme(s2mono)
graph save "${logfiles}\FigureA2PanelC_public.gph", replace
graph export "${logfiles}\FigureA2PanelC_public.eps", as(eps) replace
graph export "${logfiles}\FigureA2PanelC_public.pdf", as(pdf) replace

erase "${logfiles}\juego8_public.gph" 
erase "${logfiles}\juego9_public.gph"


****************************************************
** One vs two weeks, non-public

graph twoway (bar juego8_3_early_non early_treated if early_treated==1 & public==0, fcolor(white)) ///
(bar juego8_3_early_non early_treated if early_treated==2 & public==0, fcolor(gray)) ///
(rcap l_juego8_3_early_non u_juego8_3_early_non early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=1" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego8_non.gph", replace

graph twoway (bar juego9_3_early_non early_treated if early_treated==1 & public==0, fcolor(white)) ///
(bar juego9_3_early_non early_treated if early_treated==2 & public==0, fcolor(gray)) ///
(rcap l_juego9_3_early_non u_juego9_3_early_non early_treated), ylabel(0(0.2)1.6) ///
legend(row(1) order (1 "Treated Jan-Mar" 2 "Control")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("R=2" ) graphregion(fcolor(white))


graph save Graph "${logfiles}\juego9_non.gph", replace


gr combine "${logfiles}\juego8_non.gph" "${logfiles}\juego9_non.gph", ycommon title("Non-Public: One week vs. Two weeks") graphregion(fcolor(white))

graph save "${logfiles}\FigureA2PanelC_non.gph", replace
graph use "${logfiles}\FigureA2PanelC_non.gph", scheme(s2mono)
graph save "${logfiles}\FigureA2PanelC_non.gph", replace
graph export "${logfiles}\FigureA2PanelC_non.eps", as(eps) replace
graph export "${logfiles}\FigureA2PanelC_non.pdf", as(pdf) replace

erase "${logfiles}\juego8_non.gph" 
erase "${logfiles}\juego9_non.gph"


log close
