*File Name: Experimento // CTB_horizontal_may2023
*This version: April 2016 // May 2023
*Authors: Laura Hospido (laura.hospido@bde.es) - Ernesto Villanueva
*--------------------------------------------------------------------------
* Please notify and cite the authors to distribute and/or modify this work.
*--------------------------------------------------------------------------
set more off
clear all
cap log close
*cd "D:\BdE\EducacionFinanciera\BdE\2015\Datos"

**global datos_diciembre "C:\trabajo\new_projects\FInancial-literacy-eval 2014-2015\Virginia\Diciembre\Database"
**global datos_junio "C:\trabajo\new_projects\FInancial-literacy-eval 2014-2015\Virginia\Junio\Database"
**global logfiles "C:\trabajo\new_projects\FInancial-literacy-eval 2014-2015\Virginia\Junio\logfiles_Apr16"

global datos_junio "C:\Users\Usuario\Dropbox\JHR\replication file\datafiles"
global logfiles "C:\Users\Usuario\Dropbox\JHR\replication file\logfiles\"
global graphfiles "C:\Users\Usuario\Dropbox\JHR\replication file\graphfiles\test"
global graphfiles_repl "C:\Users\Usuario\Dropbox\JHR\Submission\Figures"


log using "${logfiles}Figure2 test panels AB.log",replace

**********************************************************************************
********************************* UNBALANCED SAMPLE ******************************
**********************************************************************************

******************
**** BALANCED ****
******************

use "${datos_junio}\Students", clear


*** MADRID ONLY  ***

keep if stratum_c == 1|  stratum_c == 2 | stratum_c == 3 | (stratum_c==7)

qui compress


gen		treatment=1 if curso==3
replace treatment=0 if curso==4

egen cluster_cole=group(COD_CENTRO curso)

replace stratum_c11=1 if stratum_c12==1
drop stratum_c12 stratum_c

gen 	b100_120=(december_CA_P11A==1)
replace b100_120=. if (december_CA_P11A==3|december_CA_P11A==.)
drop if b100_120==.

gen 	b100_150=(december_CA_P11B==1)
replace b100_150=. if (december_CA_P11B==3|december_CA_P11B==.)
drop if b100_150==.

gen 	b100_180=(december_CA_P11C==1)
replace b100_180=. if (december_CA_P11C==3|december_CA_P11C==.)
drop if b100_180==.


/* ********************* HYPOTHETICAL CHOICES ******************* */


gen 	early_treated=1 if (curso==3& treated==1)	/* Schools treated in Jan March, 9th graders*/
replace early_treated=2 if (curso==4)				/*All  10th graders*/
replace early_treated=3 if (curso==3& treated==0)	/* Schools treated in April June, 9th graders*/

drop if early_treated==3

*Early treated

foreach x in b100_120 b100_150 b100_180{
	
	reg `x' if early_treated==1, cluster(cluster_cole)
	gen `x'_3_early=_b[_cons] if early_treated==1
	mat A=get(VCE)
	gen sd_`x'_3_early=A[1,1]^.5 if early_treated==1

	gen l_`x'_3_early=`x'_3_early-1.96*sd_`x'_3_early if early_treated==1
	gen u_`x'_3_early=`x'_3_early+1.96*sd_`x'_3_early if early_treated==1

*Controls

	reg `x' if early_treated==2, cluster(cluster_cole)
	replace `x'_3_early=_b[_cons] if early_treated==2
	mat A=get(VCE)
	replace sd_`x'_3_early=A[1,1]^.5 if early_treated==2

	replace l_`x'_3_early=`x'_3_early-1.96*sd_`x'_3_early if early_treated==2
	replace u_`x'_3_early=`x'_3_early+1.96*sd_`x'_3_early if early_treated==2
	
}

***100 vs 120

graph twoway (bar b100_120_3_early early_treated if early_treated==1, fcolor(white)) /// 
(bar b100_120_3_early early_treated if early_treated==2, fcolor(gray)) /// 
(rcap l_b100_120_3_early u_b100_120_3_early early_treated), ylabel(0(0.1)0.3) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("100 euros today vs 120 in 3 weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\100vs120.gph", replace

***100 vs 150

graph twoway (bar b100_150_3_early early_treated if early_treated==1, fcolor(white)) /// 
(bar b100_150_3_early early_treated if early_treated==2, fcolor(gray)) /// 
(rcap l_b100_150_3_early u_b100_150_3_early early_treated), ylabel(0(0.1)0.3) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("100 euros today vs 150 in 3 weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\100vs150.gph", replace

***100 vs 180

graph twoway (bar b100_180_3_early early_treated if early_treated==1, fcolor(white)) /// 
(bar b100_180_3_early early_treated if early_treated==2,fcolor(gray)) /// 
(rcap l_b100_180_3_early u_b100_180_3_early early_treated), ylabel(0(0.1)0.3) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("100 euros today vs 180 in 3 weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\100vs180.gph", replace

gr combine "${graphfiles}\100vs120.gph" "${graphfiles}\100vs150.gph" "${graphfiles}\100vs180.gph", /*
*/ col(3) ycommon title("Hypothetical choices at baseline") subtitle("Early Treated (9th graders) vs Control (10th graders)") graphregion(fcolor(white))

graph save "${graphfiles}\Figure1_hyp.gph", replace
graph use "${graphfiles}\Figure1_hyp.gph", scheme(s2mono)
graph save "${graphfiles}\Figure1_hyp.gph", replace

graph export "${graphfiles}\Figure1_hyp.eps", as(eps) replace
graph export "${graphfiles_repl}\Figure1_PanelAhyp.pdf", as(pdf) replace


erase "${graphfiles}\100vs120.gph" 
erase "${graphfiles}\100vs150.gph"
erase "${graphfiles}\100vs180.gph"




******************************* OUTCOME IN CONVEX TIME BUDGET TREATED IN JANUARY-MARCH ***********************
* Today vs. One week *


* R=1
reg juego2 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (curso==4 | (curso==3 & treated==1)), robust cluster(cluster_cole)

* R=2 
reg juego3 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (curso==4 | (curso==3 & treated==1)), robust cluster(cluster_cole)

* Today vs. Two weeks *

* R=1
reg juego5 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (curso==4 | (curso==3 & treated==1)), robust cluster(cluster_cole)

* R=2

reg juego6 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (curso==4 | (curso==3 & treated==1)), robust cluster(cluster_cole)

* One week vs. Two weeks *
* R=1

reg juego8 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (curso==4 | (curso==3 & treated==1)), robust cluster(cluster_cole)

* R=12
reg juego9 treatment stratum_c2 stratum_c3 stratum_c7 b100_120  b100_150 b100_180 if (curso==4 | (curso==3 & treated==1)), robust cluster(cluster_cole)


/* TREATMENT GRAPH */


*Early treated

foreach x in juego2 juego3 juego5 juego6 juego8 juego9{
	
	reg `x' if early_treated==1, cluster(cluster_cole)
	gen `x'_3_early=_b[_cons] if early_treated==1
	mat A=get(VCE)
	gen sd_`x'_3_early=A[1,1]^.5 if early_treated==1

	gen l_`x'_3_early=`x'_3_early-1.96*sd_`x'_3_early if early_treated==1
	gen u_`x'_3_early=`x'_3_early+1.96*sd_`x'_3_early if early_treated==1

*Controls

	reg `x' if early_treated==2, cluster(cluster_cole)
	replace `x'_3_early=_b[_cons] if early_treated==2
	mat A=get(VCE)
	replace sd_`x'_3_early=A[1,1]^.5 if early_treated==2

	replace l_`x'_3_early=`x'_3_early-1.96*sd_`x'_3_early if early_treated==2
	replace u_`x'_3_early=`x'_3_early+1.96*sd_`x'_3_early if early_treated==2
	
}


/* ********************* OUTCOME IN THE CONVEX TIME BUDGET EARLY TREATED: GRAPHS  *************** */


/* ** Today vs one week ** */

graph twoway (bar juego2_3_early early_treated if early_treated==1, fcolor(white)) ///
(bar juego2_3_early early_treated if early_treated==2, fcolor(gray)) ///
(rcap l_juego2_3_early u_juego2_3_early early_treated), ylabel(0(0.4)1.6) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("Today vs one week" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\juego2.gph", replace

graph twoway (bar juego3_3_early early_treated if early_treated==1, fcolor(white)) ///
(bar juego3_3_early early_treated if early_treated==2, fcolor(gray)) ///
(rcap l_juego3_3_early u_juego3_3_early early_treated), ylabel(0(0.4)1.6) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("Today vs one week" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\juego3.gph", replace
/*
gr combine "${graphfiles}\juego2.gph" "${graphfiles}\juego3.gph", ycommon title("Today vs. One week") graphregion(fcolor(white))
graph save "${graphfiles}\Graph1A.gph", replace
graph export "${graphfiles}\Graph1A.eps", as(eps) replace

erase "${graphfiles}\juego2.gph" 
erase "${graphfiles}\juego3.gph"
*/

** Today vs two weeks

graph twoway (bar juego5_3_early early_treated if early_treated==1, fcolor(white)) ///
(bar juego5_3_early early_treated if early_treated==2, fcolor(gray)) ///
(rcap l_juego5_3_early u_juego5_3_early early_treated), ylabel(0(0.4)1.6) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("Today vs two weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\juego5.gph", replace

graph twoway (bar juego6_3_early early_treated if early_treated==1, fcolor(white)) ///
(bar juego6_3_early early_treated if early_treated==2, fcolor(gray)) ///
(rcap l_juego6_3_early u_juego6_3_early early_treated), ylabel(0(0.4)1.6) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("Today vs two weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\juego6.gph", replace
/*
gr combine "${graphfiles}\juego5.gph" "${graphfiles}\juego6.gph", ycommon title("Today vs. Two weeks") graphregion(fcolor(white))
graph save "${graphfiles}\Graph1B.gph", replace
graph export "${graphfiles}\Graph1B.eps", as(eps) replace

erase "${graphfiles}\juego5.gph" 
erase "${graphfiles}\juego6.gph"
*/
** One vs two weeks

graph twoway (bar juego8_3_early early_treated if early_treated==1, fcolor(white)) ///
(bar juego8_3_early early_treated if early_treated==2, fcolor(gray)) ///
(rcap l_juego8_3_early u_juego8_3_early early_treated), ylabel(0(0.4)1.6) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("One vs two weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\juego8.gph", replace

graph twoway (bar juego9_3_early early_treated if early_treated==1, fcolor(white)) ///
(bar juego9_3_early early_treated if early_treated==2, fcolor(gray)) ///
(rcap l_juego9_3_early u_juego9_3_early early_treated), ylabel(0(0.4)1.6) ///
legend(row(1) order (1 "T=1" 2 "T=0")) ///
xlabel(1 " " 2 " ", noticks) ///
xtitle("One vs two weeks" ) graphregion(fcolor(white))

graph save Graph "${graphfiles}\juego9.gph", replace



/* ***************************** R=100******************* */

gr combine "${graphfiles}\juego2.gph" "${graphfiles}\juego5.gph" "${graphfiles}\juego8.gph", ycommon col(3) graphregion(fcolor(white))

graph save "${graphfiles}\Figure2.gph", replace
graph use "${graphfiles}\Figure2.gph", scheme(s2mono)
graph save "${graphfiles}\Figure2.gph", replace

graph export "${graphfiles}\Figure2.eps", as(eps) replace



/* ***************************** R=200******************* */

gr combine "${graphfiles}\juego2.gph" "${graphfiles}\juego5.gph" "${graphfiles}\juego8.gph", ycommon col(3) graphregion(fcolor(white))

graph save "${graphfiles}\Figure2_panelA.gph", replace
graph use "${graphfiles}\Figure2_panelA.gph", scheme(s2mono)
graph save "${graphfiles}\Figure2_panelA.gph", replace
graph export "${graphfiles}\Figure2_panelA.eps", as(eps) replace
graph export "${graphfiles_repl}\BoverHospidoVillanuevaFigure2_panelA.pdf", as(pdf) replace


erase "${graphfiles}\juego2.gph" 
erase "${graphfiles}\juego5.gph"
erase "${graphfiles}\juego8.gph"

gr combine "${graphfiles}\juego3.gph" "${graphfiles}\juego6.gph" "${graphfiles}\juego9.gph", ycommon col(3) graphregion(fcolor(white))

graph save "${graphfiles}\Figure2_panelB.gph", replace
graph use "${graphfiles}\Figure2_panelB.gph", scheme(s2mono)
graph save "${graphfiles}\Figure2_panelB.gph", replace
graph export "${graphfiles}\Figure2_panelB.eps", as(eps) replace
graph export "${graphfiles_repl}\BoverHospidoVillanueva_Figure2_panelB.pdf", as(pdf) replace


erase "${graphfiles}\juego3.gph" 
erase "${graphfiles}\juego6.gph"
erase "${graphfiles}\juego9.gph"

log close
