* File Name: README - Codes for The Impact of High School Financial Education on
* Financial Knowledge and Choices: Evidence from a Randomized Trial in Spain
* Authors: Olympia Bover, Laura Hospido & Maria Torrado & Ernesto Villanueva
* This version: April 2020
*---------------------------------------------------------------------------
* Please notify and cite the authors to distribute and/or modify this work.
*---------------------------------------------------------------------------

clear all
set more off
*cd "X:\Dga_EI\AMicro\TRABAJO\FLIT_evaluacion_2014-2015\2020_version\"
cd "F:\BdE_11032020\FLIT_evaluacion_2014-2015\2020_version\"
*cd "E:\Dropbox\BdE\EducacionFinanciera\Programa Escolar\2015\Evaluation\2020_version\"

*****************
* RANDOMIZATION *
*****************

use "Datafiles\December2014\Centros2.dta", clear
rename Cod COD_CENTRO
rename Centro CENTRO
destring COD_CENTRO, replace
gen		treated= 1 if Tratamiento=="Enero-Marzo"
replace treated= 0 if Tratamiento=="Abril-Junio"
drop Tratamiento
** Strata **
do "Dofiles\0a. Strata.do"
qui compress
sort COD_CENTRO
save "Datafiles\December2014\Randomization.dta", replace

*** Table A.1: Description of the strata

capture log close
log using "Logfiles\TableA1.log", replace
use "Datafiles\December2014\Randomization.dta", clear
tab stratum treated
log close

******************************
* INFORMATION ON THE SCHOOLS *
******************************

use "Datafiles\December2014\Randomization.dta", clear
merge COD_CENTRO using "Datafiles\December2014\Centros1.dta"
drop _merge
*** step deleted due to anonymization
drop if COD_CENTRO=XXXXX *** step deleted due to anonymization
rename CENTRO nom_centro
rename NOM_MUNI nom_muni
foreach x in P3 P4A P4B P4C P4D P4E P5A P5B P6A P7A P7B P7C P7D P8A P8B P8C P8D P9 P10 P11 P14A ///
P15A P16A P16B P16C P16D P16E P16F P16G P16H P16I P16J P16K P16L P16M P16N P16O P16P P16Q P16R P16S P16T ///
P16_B1 P12 P12BA P12BB P12BC P12BD P13 P13B_AB P13B_C1 P13B_C2 P13B_C3 P13CA P13CB P13CC P13CD P13CE ///
P13CF P13CG P13C_B1 P13D_AB P13D_C1 P13D_C2 P13D_C3 P13E_AB P13E_C1 P13E_C2 P13FA P13G_AB P13G_C1 P13G_C2{
rename `x' school_`x'
}
qui compress
** Variables **
gen 	madrid=(ccaa=="MADRID")
gen 	madrid2=0
replace madrid2=1 if stratum_c==1|stratum_c==2|stratum_c==3|stratum_c==7

gen 	publico=(school_P3==1) 
gen 	concertado=(school_P3==2|school_P3==3)
gen 	privado=(school_P3==4|school_P3==5)
gen 	concpri=(concertado==1|privado==1) 

gen 	publico2=(stratum_c==1|stratum_c==4|stratum_c==7|stratum_c==9|stratum_c==11|stratum_c==16) // definicion que se usa en table 3
gen 	concpri2=(stratum_c==2|stratum_c==5|stratum_c==6|stratum_c==10|stratum_c==12|stratum_c==13)
replace publico2=. if stratum_c==14
replace concpri2=. if stratum_c==14

bys treated: egen sum_teachers=sum(school_P15A)

label variable madrid 		"Madrid (def. ccaa)"
label variable madrid2 		"Madrid (def. strata)"
label variable publico 		"publico (def. school quest)"
label variable concertado 	"concertado (def. school quest)"
label variable privado 		"privado (def. school quest)"
label variable concpri 		"concertado/privado (def. school quest)"
label variable publico2 	"publico (def. strata)"
label variable concpri2 	"concertado/privado (def. strata)"
label variable sum_teachers "Nºprofesores En-Mar vs Abr-Jun"
sort COD_CENTRO 
save "Datafiles\December2014\Schools.dta", replace
erase "Datafiles\December2014\Randomization.dta"

*************************
* TEACHERS' INFORMATION *
*************************

*** March 2015

use "Datafiles\March2015\Profes.dta", replace
sort COD_CENTRO cl_prof
save "temp1.dta", replace

*** June 2015

use "Datafiles\June2015\Profes_150706.dta", clear
gen time="june"
append using "temp1.dta"
replace time="march" if time==""
erase "temp1.dta"
foreach x in p4  p11a1b p11a2b p11a3b p11a4b p11a1d p11a2d p11a3d p11a4d p13a1* p13a2* p13a3* p13a4* ///
p14a1* p14a2* p14a3* p14a4* p20a1 p21a1 p20a2 p21a2 p20a3 p21a3 p20a4 p21a4 p24* p26* {
rename `x' teacher_`x'
}
keep COD_CENTRO cl_prof time teacher_*


** Variables **
gen teacher_social_science=(teacher_p4==9) 		//Teacher's specialization 
gen teacher_economics=(teacher_p4==3)
gen teacher_math=(teacher_p4==15)
gen teacher_computing_science=(teacher_p4==11|teacher_p4==18)
gen teacher_other=(teacher_p4==1|teacher_p4==6|teacher_p4==12|teacher_p4==14)

gen teacher_p24=(teacher_p24a+teacher_p24b+teacher_p24c+teacher_p24d+teacher_p24e)/5	//Teacher's assesment
gen teacher_p26=(teacher_p26a+teacher_p26b)/2
gen teacher_all=(teacher_p24a+teacher_p24b+teacher_p24c+teacher_p24d+teacher_p24e+teacher_p26a+teacher_p26b)/7
drop teacher_p26a teacher_p26b teacher_p24a teacher_p24b teacher_p24c teacher_p24d teacher_p24e
qui compress
sort COD_CENTRO cl_prof
save "Datafiles\Teachers.dta", replace

use "Datafiles\Teachers.dta", clear
destring COD_CENTRO, replace
sort COD_CENTRO cl_prof
* No tenemos info de profes para 3 centros (1 tratado y 2 controles)
merge COD_CENTRO using "Datafiles\December2014\Schools.dta"
tab _merge
keep if _merge==3
drop _merge
qui compress
save "Datafiles\Teachers.dta", replace

********************
* SAMPLE SELECTION *
********************

*** December families

use "Datafiles\December2014\CFamilias.dta", clear
append using  "Datafiles\December2014\Cfamiliasplus.dta"
foreach x in COD_INC P* {
rename `x' family_`x'
}
** Variables **
gen family_edumad_prim=0								//educacion madre
gen family_edumad_sec=0
gen family_edumad_ter=0
gen family_edumadmis=0
replace family_edumad_prim=1 	if family_P17A==1|family_P17A==2 // Primaria
replace family_edumad_sec=1 	if family_P17A==3|family_P17A==4 // Secundaria
replace family_edumad_ter=1 	if family_P17A==5|family_P17A==6|family_P17A==7|family_P17A==8 // Superiores
replace family_edumadmis=1 	if family_P17A==9|family_P17A==. // No disponible
gen family_edupad_prim=0								//educacion padre
gen family_edupad_sec=0
gen family_edupad_ter=0
gen family_edupadmis=0
replace family_edupad_prim=1 	if family_P17B==1|family_P17B==2 // Primaria
replace family_edupad_sec=1 	if family_P17B==3|family_P17B==4 // Secundaria
replace family_edupad_ter=1 	if family_P17B==5|family_P17B==6|family_P17B==7|family_P17B==8 // Superiores
replace family_edupadmis=1 	if family_P17B==9|family_P17B==. // No disponible
label variable family_edumad_prim 	"Educacion madre: primaria"
label variable family_edumad_sec 	"Educacion madre: secundaria"
label variable family_edumad_ter 	"Educacion madre: terciaria"
label variable family_edupad_prim 	"Educacion padre: primaria"
label variable family_edupad_sec 	"Educacion padre: secundaria"
label variable family_edupad_ter 	"Educacion padre: terciaria"
qui compress
sort COD_CENTRO idestu
save "Datafiles\Family.dta", replace

*** December students

use "Datafiles\December2014\Alumnos", replace
sort COD_CENTRO idestu
merge COD_CENTRO idestu using "Datafiles\Family.dta"
drop _merge
keep if nee==""
drop nee
*** Step deleted due to anonymization ***
drop if COD_CENTRO==XXXXX
rename CA_P1 sexo
** Pre-test by topic
gen		sum_correct0_Budget = (P5==2)+(P6==3)+(P7==4)+(P8==4)+(P9==4)+(P11==2)+(P26A==3)+(P27A==1)+(P28A==4)+(P30A==1) if tipocues=="A"
replace sum_correct0_Budget = (P5==2)+(P6==3)+(P7==4)+(P8==4)+(P9==4)+(P11==2)+(P21B==2) if tipocues=="B"
gen		N0_BudgetA = 10 if tipocues=="A"
gen		N0_BudgetB = 7 if tipocues=="B"
gen		sum_correct0_Money = (P13==4)+(P23A==2)+(P24A==4) if tipocues=="A"
replace sum_correct0_Money = (P13==4)+(P27B==2)+(P28B==1) if tipocues=="B"
gen		N0_MoneyA = 3 if tipocues=="A"
gen		N0_MoneyB = 3 if tipocues=="B"
gen 	sum_correct0_Banks = (P12==2)+(P14==4)+(P15==2)+(P16==3)+(P17==4)+(P18==3)+(P19==2)+(P21A==2)+(P22A==2)+(P25A==2)+(P29A==1) if tipocues=="A"
replace sum_correct0_Banks = (P12==2)+(P14==4)+(P15==2)+(P16==3)+(P17==4)+(P18==3)+(P19==2)+(P22B==2)+(P23B==2)+(P24B==3)+(P25B==3)+(P26B==4)+(P30B==1) if tipocues=="B"
gen		N0_BanksA = 11 if tipocues=="A"
gen		N0_BanksB = 13 if tipocues=="B"
gen		sum_correct0_IntCo = (P1==3)+(P2==3)+(P3==4)+(P4==3)+(P10==3)+(P20==3) if tipocues=="A"
replace sum_correct0_IntCo = (P1==3)+(P2==3)+(P3==4)+(P4==3)+(P10==3)+(P20==3)+(P29B==4) if tipocues=="B"
gen		N0_IntCoA = 6 if tipocues=="A"
gen		N0_IntCoB = 7 if tipocues=="B"
gen		pre_Test_Sav=sum_correct0_Budget/N0_BudgetA if tipocues=="A"
replace pre_Test_Sav=sum_correct0_Budget/N0_BudgetB if tipocues=="B"
gen		pre_Test_Money=sum_correct0_Money/N0_MoneyA if tipocues=="A"
replace pre_Test_Money=sum_correct0_Money/N0_MoneyB if tipocues=="B"
gen		pre_Test_Banks=sum_correct0_Banks/N0_BanksA if tipocues=="A"
replace pre_Test_Banks=sum_correct0_Banks/N0_BanksB if tipocues=="B"
gen		pre_Test_IntCo=sum_correct0_Money/N0_IntCoA if tipocues=="A"
replace pre_Test_IntCo=sum_correct0_Money/N0_IntCoB if tipocues=="B"
** Pre-test
gen P1_correct  = (P1==3)
gen P2_correct  = (P2==3)
gen P3_correct  = (P3==4)
gen P4_correct  = (P4==3)
gen P5_correct  = (P5==2)
gen P6_correct  = (P6==3)
gen P7_correct  = (P7==4)
gen P8_correct  = (P8==4)
gen P9_correct  = (P9==4)
gen P10_correct = (P10==3)
gen P11_correct = (P11==2)
gen P12_correct = (P12==2)
gen P13_correct = (P13==4)
gen P14_correct = (P14==4)
gen P15_correct = (P15==2)
gen P16_correct = (P16==3)
gen P17_correct = (P17==4)
gen P18_correct = (P18==3)
gen P19_correct = (P19==2)
gen P20_correct = (P20==3)
gen P21A_correct= (P21A==2)
gen P22A_correct= (P22A==2)
gen P23A_correct= (P23A==2)
gen P24A_correct= (P24A==4)
gen P25A_correct= (P25A==2)
gen P26A_correct= (P26A==3)
gen P27A_correct= (P27A==1)
gen P28A_correct= (P28A==4)
gen P29A_correct= (P29A==1)
gen P30A_correct= (P30A==1)
gen P21B_correct= (P21B==2)
gen P22B_correct= (P22B==2)
gen P23B_correct= (P23B==2)
gen P24B_correct= (P24B==3)
gen P25B_correct= (P25B==3)
gen P26B_correct= (P26B==4)
gen P27B_correct= (P27B==2)
gen P28B_correct= (P28B==1)
gen P29B_correct= (P29B==4)
gen P30B_correct= (P30B==1)
gen sum_correct = 0
forvalues i=1(1)20{
        qui replace sum_correct=sum_correct + P`i'_correct
		drop P`i' P`i'_correct
}
forvalues i=21(1)30{
         qui replace sum_correct=sum_correct + P`i'A_correct if tipocues=="A"
		 drop P`i'A P`i'A_correct
}
forvalues i=21(1)30{
         qui replace sum_correct=sum_correct + P`i'B_correct if tipocues=="B"
		 drop P`i'B P`i'B_correct
}
drop tipocues
gen pretest=(sum_correct/3)
drop sum_correct
replace pretest=. if Asistencia!=1
label variable pretest "Nota en diciembre 2014 (Escala 0-10 no estandarizada)"
foreach x in sexo observaciones Asistencia CA_P2 CA_P2A CA_P2A_B1 CA_P3 CA_P4 CA_P5 CA_P6 ///
CA_P7A CA_P7B CA_P7C CA_P7D CA_P7E CA_P7F CA_P8A CA_P8B CA_P9 CA_P10 CA_P11A CA_P11B CA_P11C {
rename `x' december_`x'
}
qui compress
sort COD_CENTRO idestu
save temp1, replace

*** Date of birth

use "Datafiles\March2015\Alumnosdatos.dta", replace
drop curso C10 COD_ALUM ini
rename sexo check_sexo		
rename date fecha_nacimiento
rename ID_ESTU idestu
gen 	fecha_nacimiento_a=fecha_nacimiento
gen 	fecha_nacimiento_b=fecha_nacimiento
split 	fecha_nacimiento_a, p("/") destring
split 	fecha_nacimiento_b, p("-") destring
gen 	year=fecha_nacimiento_b3 	if fecha_nacimiento_b3!=.
gen 	month=fecha_nacimiento_b2 	if fecha_nacimiento_b2!=.
gen 	day=fecha_nacimiento_b1 	if fecha_nacimiento_b2!=.
destring day, replace
drop fecha_nacimiento_b fecha_nacimiento_b1 fecha_nacimiento_b2 fecha_nacimiento_b3
qui compress
replace year=fecha_nacimiento_a3 	if year==.
replace fecha_nacimiento_a1="" 		if month!=.
destring fecha_nacimiento_a1, replace
gen 	corrected_fecha_nacimiento_a1=fecha_nacimiento_a1
gen 	correction=(fecha_nacimiento_a1!=.&fecha_nacimiento_a1>12)
replace corrected_fecha_nacimiento_a1=fecha_nacimiento_a2 if fecha_nacimiento_a1!=.&fecha_nacimiento_a1>12
replace fecha_nacimiento_a2=fecha_nacimiento_a1 if correction==1
replace day=fecha_nacimiento_a2 if day==.
replace month=corrected_fecha_nacimiento_a1 if month==.
rename day dia_nacimiento
rename month mes_nacimiento
rename year año_nacimiento
drop fecha_nacimiento_a fecha_nacimiento_a1 fecha_nacimiento_a2 fecha_nacimiento_a3 corrected_fecha_nacimiento_a1 correction
sort COD_CENTRO idestu
save temp2, replace

*** March students

use "Datafiles\March2015\Datos_Aplicacion2_rev.dta", replace
sort COD_CENTRO idestu
merge COD_CENTRO idestu using temp2
drop _merge
keep if nee==""
drop nee
*** Step deleted due to anonymization ***
drop if COD_CENTRO==XXXXX
rename CA_C1 sexo
replace sexo=1 if check_sexo==2&(sexo==0|sexo==.)
replace sexo=2 if check_sexo==1&(sexo==0|sexo==.)
drop check_sexo
rename TIPOCUES2 tipo_cuestionario
** Post-test by topic
gen		sum_correct1_Budget = (PP1==3)+(PP15==2)+(PP21A==2) if tipo_cuestionario=="A"
replace sum_correct1_Budget = (PP1==3)+(PP15==2)+(PP26B==3)+(PP27B==1)+(PP28B==4)+(PP30B==1) if tipo_cuestionario=="B"
gen		N1_BudgetA = 3 if tipo_cuestionario=="A"
gen		N1_BudgetB = 6 if tipo_cuestionario=="B"
gen		sum_correct1_Money = (PP2==2)+(PP3==4)+(PP4==4)+(PP27A==2)+(PP28A==1) if tipo_cuestionario=="A"
replace sum_correct1_Money = (PP2==2)+(PP3==4)+(PP4==4)+(PP23B==2)+(PP24B==4) if tipo_cuestionario=="B"
gen		N1_MoneyA = 5 if tipo_cuestionario=="A"
gen		N1_MoneyB = 5 if tipo_cuestionario=="B"
gen 	sum_correct1_Banks = (PP5==2)+(PP6==4)+(PP10==4)+(PP11==4)+(PP12==3)+(PP13==2)+(PP14==2)+(PP16==4)+(PP17==4)+(PP18==4)+(PP19==3)+(PP20==4)+(PP22A==2)+(PP23A==2)+(PP24A==3)/*
*/+(PP25A==2)+(PP26A==4)+(PP30A==1) if tipo_cuestionario=="A"
replace sum_correct1_Banks = (PP5==2)+(PP6==4)+(PP10==4)+(PP11==4)+(PP12==3)+(PP13==2)+(PP14==2)+(PP16==4)+(PP17==4)+(PP18==4)+(PP19==3)+(PP20==4)+(PP21B==2)+(PP22B==2)+(PP25B==2)/*
*/ +(PP29B==1) if tipo_cuestionario=="B"
gen		N1_BanksA = 18 if tipo_cuestionario=="A"
gen		N1_BanksB = 16 if tipo_cuestionario=="B"
gen		sum_correct1_IntCo = (PP7==1)+(PP8==4)+(PP9==1)+(PP29A==4) if tipo_cuestionario=="A"
replace sum_correct1_IntCo = (PP7==1)+(PP8==4)+(PP9==1) if tipo_cuestionario=="B"
gen		N1_IntCoA = 4 if tipo_cuestionario=="A"
gen		N1_IntCoB = 3 if tipo_cuestionario=="B"
gen		post_Test_Sav=sum_correct1_Budget/N1_BudgetA if tipo_cuestionario=="A"
replace post_Test_Sav=sum_correct1_Budget/N1_BudgetB if tipo_cuestionario=="B"
gen		post_Test_Money=sum_correct1_Money/N1_MoneyA if tipo_cuestionario=="A"
replace post_Test_Money=sum_correct1_Money/N1_MoneyB if tipo_cuestionario=="B"
gen		post_Test_Banks=sum_correct1_Banks/N1_BanksA if tipo_cuestionario=="A"
replace post_Test_Banks=sum_correct1_Banks/N1_BanksB if tipo_cuestionario=="B"
gen		post_Test_IntCo=sum_correct1_Money/N1_IntCoA if tipo_cuestionario=="A"
replace post_Test_IntCo=sum_correct1_Money/N1_IntCoB if tipo_cuestionario=="B"
*** Post-test
gen PP1_correct  = (PP1==3)
gen PP2_correct  = (PP2==2)
gen PP3_correct  = (PP3==4)
gen PP4_correct  = (PP4==4)
gen PP5_correct  = (PP5==2)
gen PP6_correct  = (PP6==4)
gen PP7_correct  = (PP7==1)
gen PP8_correct  = (PP8==4)
gen PP9_correct  = (PP9==1)
gen PP10_correct = (PP10==4)
gen PP11_correct = (PP11==4)
gen PP12_correct = (PP12==3)
gen PP13_correct = (PP13==2)
gen PP14_correct = (PP14==2)
gen PP15_correct = (PP15==2)
gen PP16_correct = (PP16==4)
gen PP17_correct = (PP17==4)
gen PP18_correct = (PP18==4)
gen PP19_correct = (PP19==3)
gen PP20_correct = (PP20==4)
gen PP21A_correct= (PP21A==2)
gen PP22A_correct= (PP22A==2)
gen PP23A_correct= (PP23A==2)
gen PP24A_correct= (PP24A==3)
gen PP25A_correct= (PP25A==3)
gen PP26A_correct= (PP26A==4)
gen PP27A_correct= (PP27A==2)
gen PP28A_correct= (PP28A==1)
gen PP29A_correct= (PP29A==4)
gen PP30A_correct= (PP30A==1)
gen PP21B_correct= (PP21B==2)
gen PP22B_correct= (PP22B==2)
gen PP23B_correct= (PP23B==2)
gen PP24B_correct= (PP24B==4)
gen PP25B_correct= (PP25B==2)
gen PP26B_correct= (PP26B==3)
gen PP27B_correct= (PP27B==1)
gen PP28B_correct= (PP28B==4)
gen PP29B_correct= (PP29B==1)
gen PP30B_correct= (PP30B==1)

gen sum_correct = 0
forvalues i=1(1)20{
	qui replace sum_correct=sum_correct + PP`i'_correct
	drop PP`i' PP`i'_correct
}
qui replace sum_correct=sum_correct + PP21A_correct if tipo_cuestionario=="A"
drop PP21A PP21A_correct
forvalues i=23(1)30{
	qui replace sum_correct=sum_correct + PP`i'A_correct if tipo_cuestionario=="A"
	drop PP`i'A PP`i'A_correct
}
forvalues i=21(1)30{
	qui replace sum_correct=sum_correct + PP`i'B_correct if tipo_cuestionario=="B"
	drop PP`i'B PP`i'B_correct
}
gen postest=(sum_correct/2.9) if tipo_cuestionario=="A"
replace postest=(sum_correct/3) if tipo_cuestionario=="B"
replace postest=. if Asistencia2!=1
label variable postest "Nota en marzo 2015 (Escala 0-10 no estandarizada)"
drop tipo_cuestionario sum_correct ENUN_P22A PP22A PP22A_correct
foreach x in sexo ESTADO1 ESTADO2 ESTADO3 CL_PROF1 CL_PROF2 CL_PROF3  Asistencia2 ///
observaciones CA_C2 CA_C2A CA_C2A_B1 CA_C3 CA_C3_B1 CA_C4 CA_C4_B1 CA_C5 CA_C6A CA_C6B CA_C6C CA_C6D ///
CA_C6E CA_C6F CA_C7A CA_C7B CA_C8 CA_C9 CA_C10 CA_C11 CA_C12 PP31 PP32 PP33 {
rename `x' march_`x'
}
rename march_Asistencia2 march_Asistencia
gen repetidores=(año_nacimiento<2000&curso==3)
replace repetidores=1 if (año_nacimiento<1999&curso==4)
replace repetidores=. if (año_nacimiento==.)
gen repetidores_mis=(año_nacimiento==.)
label variable repetidores "Older than normal progression"
qui compress
sort COD_CENTRO idestu
save temp3, replace
erase temp2.dta

*** Merge students in december & march

use temp1, clear
merge COD_CENTRO idestu using temp3
replace repetidores_mis=1 if repetidores==.
gen 	sexo=december_sexo
replace sexo=march_sexo if sexo==.
drop december_sexo march_sexo 
label variable sexo "Sexo"
gen female=(sexo==2)
gen female_mis=(sexo==.)
label variable female "Female"
gen native=december_CA_P2
replace native=march_CA_C2 if native==.
replace native=. if native==0
replace native=0 if native==2
gen foreign=december_CA_P2 
replace foreign=march_CA_C2 if foreign==.
replace foreign=. if foreign==0
replace foreign=0 if foreign==1
replace foreign=1 if foreign==2
gen foreign_mis=(foreign==.)
drop december_CA_P2 december_CA_P2A december_CA_P2A_B1 march_CA_C2 march_CA_C2A march_CA_C2A_B1 
label variable native 	"Nacio en España"
label variable foreign 	"Nacio fuera de España"
replace march_ESTADO1=2 if _merge==1
replace march_ESTADO2=2 if _merge==1
replace march_Asistencia=5 if _merge==1
rename march_ESTADO1 altasybajas
rename march_ESTADO2 participacion
rename _merge merge_students
label variable merge_students "Merge Diciembre y Marzo"
sort COD_CENTRO idestu
merge COD_CENTRO using "Datafiles\December2014\Schools.dta"
drop _merge
replace march_ESTADO3=2 if COD_CENTRO==11062245
replace march_ESTADO3=1 if COD_CENTRO==14281273
replace march_ESTADO3=2 if COD_CENTRO==17462231
rename march_ESTADO3 compliance
label variable nom_centro 	"Nombre del centro"
label variable treated 		"Tratamiento"
label variable stratum  	"Estrato"
label variable stratum_c  	"Estrato consolidado"
qui compress
** Variables **
do "Dofiles\0b. Variables.do"
qui compress 
sort COD_CENTRO idestu
save "Datafiles\StudentsDM", replace
erase temp1.dta
erase temp3.dta
tab march_Asistencia if curso==3 ,m 
tab march_Asistencia if curso==3 &pretest!=. ,m 
tab march_Asistencia if curso==4 ,m 
tab march_Asistencia if curso==4 &pretest!=. ,m 

*** Table W.1: Evaluation sample

capture log close
log using "Logfiles\TableW1.log", replace
use "Datafiles\StudentsDM", clear
* 1. Total number of students registered in school in December 2014
tab curso if merge_students==1|merge_students==3,m
* Rows 2, 3, 4 and 5
bys curso: tab december_Asistencia if merge_students==1|merge_students==3,m
* Row 6: sample used in the balancing tests
gen balancing_test=(december_Asistencia!=0&(merge_students==1|merge_students==3))
bys curso: tab balancing_test,m
* Sample in march
tab march_Asistencia if merge_students==2&curso==3 /** the 23 new students completed the exam ***/
bys december_Asistencia: tab march_Asistencia if curso==3&(merge_students==1|merge_students==3),m /** the rest of cells in the table ***/
* Balanced sample
gen balanced_sample=(pretest!=.&postest!=.)
bys curso: tab balanced_sample,m
log close
label variable balancing_test "(=1) Sample used in balancing tests"
label variable balanced_sample "(=1) Balanced sample in March 2015"
save "Datafiles\StudentSamples", replace
erase "Datafiles\StudentsDM.dta"

*** June

use "Datafiles\June2015\Datos_Aplicacion3", replace
keep if nee==""
drop nee COD_ALUM
*** Step deleted fue to anonymization ***
drop if COD_CENTRO==XXXXXXX
drop CL_PROF4

** Post-test (june)
gen PPP1_correct  = (PPP1==2)
gen PPP2_correct  = (PPP2==2)
gen PPP3_correct  = (PPP3==3)
gen PPP4_correct  = (PPP4==4)
gen PPP5_correct  = (PPP5==2)
gen PPP6_correct  = (PPP6==2)
gen PPP7_correct  = (PPP7==4)
gen PPP8_correct  = (PPP8==3)
gen PPP9_correct  = (PPP9==1)
gen PPP10_correct = (PPP10==3)
gen PPP11_correct = (PPP11==1)
gen PPP12_correct = (PPP12==4)
gen PPP13_correct = (PPP13==3)
gen PPP14_correct = (PPP14==1)
gen PPP15_correct = (PPP15==2)
gen PPP16_correct = (PPP16==4)
gen PPP17_correct = (PPP17==2)
gen PPP18_correct = (PPP18==4)
gen PPP19_correct = (PPP19==4)
gen PPP20_correct = (PPP20==2)
gen PPP21_correct = (PPP21==4)
gen PPP22_correct = (PPP22==3)
gen PPP23_correct = (PPP23==2)
gen PPP24_correct = (PPP24==3)
gen PPP25_correct =(PPP25==4)

gen sum_correct = 0
forvalues i=1(1)25{
	qui replace sum_correct=sum_correct + PPP`i'_correct
	drop PPP`i' PPP`i'_correct
}
gen june_postest=(sum_correct/2.5) 
replace june_postest=. if Asistencia3!=1
label variable june_postest "Nota en junio 2015 (Escala 0-10 no estandarizada)"

foreach x in curso ESTADO1 ESTADO2 ESTADO3 CL_PROF1 CL_PROF2 CL_PROF3 Asistencia3 ///
observaciones {
rename `x' june_`x'
}
rename june_Asistencia3 june_Asistencia
qui compress

set more off
local i=1
while	`i'<=9 {
	qui gen 	juego`i'=6 if J`i'=="A"
	qui replace juego`i'=4 if J`i'=="B"
	qui replace juego`i'=2 if J`i'=="C"
	qui replace juego`i'=0 if J`i'=="D"
	drop if juego`i'==.
	qui compress
local i = `i' + 1
}
sort COD_CENTRO idestu
save temp1, replace

*** Merge December & March & June
use "Datafiles\StudentSamples", replace
sort COD_CENTRO idestu
merge COD_CENTRO idestu using temp1
replace curso=june_curso if curso==.&june_curso!=.
foreach x in dec100_120 mar100_120 E_dropA E_drop18 talk0 talk1 /*
*/ paga_tcasa_0 paga_tcasa_1 paga_ntcasa_0 paga_ntcasa_1 trab_ocas_0 trab_ocas_1 /*
*/ paga_negociof_0 paga_negociof_1 labor_inside_0 labor_inside_1 /*
*/ paga_fam_0 paga_fam_1 venta_internet_0 venta_internet_1 /*
*/ labor_outside_0 labor_outside_1 labor_income_1 labor_income_0 /*
*/ autonomom female foreign repetidores {
replace `x'_mis=1 if _merge==2
}
replace balancing_test=0 	if _merge==2
replace balanced_sample=0 	if _merge==2
replace treated=1		if COD_CENTRO==2441203		//"Enero-Marzo"
replace treated=0		if COD_CENTRO==13262352		//"Abril-Junio"
replace treated=1		if COD_CENTRO==14281269		//"Enero-Marzo"
replace stratum=4		if COD_CENTRO==2441203	
replace stratum=13		if COD_CENTRO==13262352
replace stratum=1		if COD_CENTRO==14281269	
replace stratum_c=4		if COD_CENTRO==2441203	
replace stratum_c=13	if COD_CENTRO==13262352
replace stratum_c=1		if COD_CENTRO==14281269
* Strata dummies
tab stratum, gen(stra)
forvalues i=1(1)7{
 gen stratum_c`i'=(stratum_c==`i')
 }
 forvalues i=9(1)14{
 gen stratum_c`i'=(stratum_c==`i')
 
 }
gen stratum_c16=(stratum_c==16)
gen june_balanced_sample=(pretest!=.&june_postest!=.)
label variable june_balanced_sample "(=1) Balanced sample in June 2015"
tab june_Asistencia if curso==3
tab treated if june_Asistencia==1&curso==3
tab june_Asistencia if curso==3&pretest!=.
tab treated if june_Asistencia==1&curso==3 &pretest!=.
tab treated if june_Asistencia==1&curso==3 &pretest!=.&june_postest!=.
tab treated if june_Asistencia==1&curso==3&june_balanced_sample==1
*drop june_curso _merge
sort COD_CENTRO idestu
qui compress
save "Datafiles\Students", replace
erase "Datafiles\StudentSamples.dta"
erase temp1.dta


/*** Table 1: Evaluation calendar

*** Table A3: Compliance and Program Implementation 

do "Dofiles\TableA3_by_titularidad.do"
do "Dofiles\TableA3_by_treated.do"
do "Dofiles\TableA3_titularidad_castellano_estudiantes.do"

*** Table 2: Student Characteristics

do "Dofiles\Table2.do"

*** Table 3: The effect of the financial literacy program on normalized tests scores

do "Dofiles\Table3.do"

*** Table 4: The effect of the financial literacy program on attitudes

do "Dofiles\Table4PanelAC.do"
do "Dofiles\Table4PanelAC_MHT.do"

*** Table 4B: The effect of the financial literacy program on sources of income

do "Dofiles\Table4PanelB.do"
do "Dofiles\Table4PanelB_MHT.do"

*** Table 4D: Results from the incentivized saving task (Convex Time Budget Task)

do "Dofiles\Table4PanelD.do"
do "Dofiles\TablePanelD_MHT.do"

*** Table 5: The effect of the financial literacy program by strata

do "Dofiles\Table5.do"
do "Dofiles\Table5_MHT.do"
do "Dofiles\Table5_savingtask_MHT.do" //Incentivized saving task sample


*** Table A.1: The effect of the financial literacy program on the March tests scores by topic

do "Dofiles\TableA.1.do"

*/
