clear all
cap log close
set more off

/* November 5th, 2023*/

cd "C:\Users\Usuario\Dropbox\JHR\replication file"

*ssc install outreg

log using "C:\Users\Usuario\Dropbox\JHR\replication file november\Tables\Table2\Table2.log", replace

*****************
**** Table 2 ****
*****************

use "Datafiles\Students", clear

label variable madrid 			"Madrid"	//(def. ccaa)
label variable madrid2 			"Madrid"	//(def. strata)
label variable publico 			"Public school"		//(def. school quest)
label variable concertado 		"Concerted school" //(def. school quest)
label variable privado 			"Private school"	//(def. school quest)
label variable concpri 			"Concerted/private" //(def. school quest)
label variable publico2 		"Public school"		//(def. strata)
label variable concpri2 		"Concerted/private" //(def. strata)

label variable pretest 			"Pre-test score (scale: 0-10, non-standardized)"
gen fraction_pretest=pretest/10
label variable fraction_pretest "Fraction of correct answers in pre-test"

label variable female 			"Female"
label variable foreign 			"Foreign born"
label variable foreign_mis 		"Foreign born missing"
label variable repetidores 		"Older than normal progression"
label variable repetidores_mis 	"Older than normal progression missing"

label variable E_dropA 			"Expected age finish school"
label variable E_drop18 		"Expect to finish at 18 or earlier"
label variable E_dropA_mis 		"Expected age finish school missing"

label variable labor_inside_0 		"Sources of income: Family business/allowance home duties"
label variable paga_fam_0 			"Sources of income: Unconditional allowances"
label variable labor_outside_0 		"Sources of income: Occasional jobs"
label variable labor_inside_0_mis 	"Sources of income: Family business/allowance home duties missing"
label variable paga_fam_0_mis		"Sources of income: Unconditional allowances missing"
label variable labor_outside_0_mis	"Sources of income: Occasional jobs missing"

label variable dec100_120 		"Prefers 100 euro today to 120 in three weeks"
label variable dec100_150 		"Prefers 100 euro today to 150 in three weeks"
label variable dec100_180 		"Prefers 100 euro today to 180 in three weeks"
label variable dec100_120_mis 	"Prefers 100 euro today to 120 in three weeks missing"
label variable dec100_150_mis 	"Prefers 100 euro today to 150 in three weeks missing"
label variable dec100_180_mis 	"Prefers 100 euro today to 180 in three weeks missing"

label variable daily0 			"Talk to parents about economics: More than once a week"
label variable onceweek0 		"Talk to parents about economics: Once a week"
label variable bonceweek0 		"Talk to parents about economics: Less than once a week"
label variable nevertalk0 		"Talk to parents about economics: Never"
label variable talk0_mis 		"Talk to parents about economics: Missing"

label variable autonomop 		"Labour status of the father: Self-employed"
label variable trabajaempp 		"Labour status of the father: Employee"
label variable paradop 			"Labour status of the father: Unemployed"
label variable other_labp 		"Labour status of the father: Does not work/other"
label variable autonomom 		"Labour status of the mother: Self-employed"
label variable trabajaempm 		"Labour status of the mother: Employee"
label variable paradom 			"Labour status of the mother: Unemployed"
label variable other_labm 		"Labour status of the mother: Does not work/other"
label variable autonomop_mis	"Labour status of the father: Missing"
label variable autonomom_mis	"Labour status of the mother: Missing"

count 
keep if balancing_test==1&curso==3
count
bys COD_CENTRO: gen n=_n
tab treated if n==1
bys COD_CENTRO: gen npublico=_n if publico2==1
tab treated if npublico==1
bys COD_CENTRO: gen nnopublico=_n if publico2==0
tab treated if nnopublico==1

global DESCVARS madrid madrid2 publico concertado privado concpri publico2 concpri2 /*
*/ fraction_pretest female foreign foreign_mis repetidores repetidores_mis E_dropA E_drop18 E_dropA_mis /*
*/ labor_inside_0 labor_inside_0_mis paga_fam_0 paga_fam_0_mis labor_outside_0 labor_outside_0_mis /*
*/ dec100_120 dec100_120_mis dec100_150 dec100_150_mis dec100_180 dec100_180_mis /*
*/ daily0 onceweek0 bonceweek0	nevertalk0 talk0_mis /*
*/ autonomop trabajaempp paradop other_labp autonomop_mis /*
*/ autonomom trabajaempm paradom other_labm autonomom_mis
foreach var in $DESCVARS {
sum `var' if balancing_test==1&curso==3
sum `var' if balancing_test==1&curso==3&treated==1
sum `var' if balancing_test==1&curso==3&treated==0
}


* p-value of differences
global DESCVARS1 fraction_pretest madrid publico concertado privado concpri /*
*/ female foreign repetidores E_dropA E_drop18 /*
*/ labor_inside_0 paga_fam_0 labor_outside_0 /*
*/ dec100_120 dec100_150 dec100_180 /*
*/ daily0 onceweek0 bonceweek0 nevertalk0 /*
*/ autonomop trabajaempp paradop other_labp /*
*/ autonomom trabajaempm paradom other_labm

* all
foreach x in $DESCVARS1 {
	di "`x'"
	reg `x' treated stratum_c2-stratum_c16 if `x'!=.&balancing_test==1&curso==3, cluster(COD_CENTRO)
}
*public
foreach x in $DESCVARS1 {
	di "`x'"
	reg `x' treated stratum_c2-stratum_c16 if `x'!=.&balancing_test==1&curso==3&publico2==1&(stratum!=14&stratum!=15), cluster(COD_CENTRO)
}
*non public
foreach x in $DESCVARS1 {
	di "`x'"
	reg `x' treated stratum_c2-stratum_c16 if `x'!=.&balancing_test==1&curso==3&publico2==0&(stratum!=14&stratum!=15), cluster(COD_CENTRO)
}


* Excel
cd "C:\Users\Usuario\Dropbox\JHR\replication file november\Tables\Table2\Tables"
putexcel set EvaluacionCorto.xlsx, sheet(Table2) modify
local x madrid madrid2 publico concertado privado concpri publico2 concpri2 /*
*/ fraction_pretest female foreign foreign_mis repetidores repetidores_mis E_dropA E_drop18 E_dropA_mis /*
*/ labor_inside_0 labor_inside_0_mis paga_fam_0 paga_fam_0_mis labor_outside_0 labor_outside_0_mis /*
*/ dec100_120 dec100_120_mis dec100_150 dec100_150_mis dec100_180 dec100_180_mis /*
*/ daily0 onceweek0 bonceweek0	nevertalk0 talk0_mis /*
*/ autonomop trabajaempp paradop other_labp autonomop_mis /*
*/ autonomom trabajaempm paradom other_labm autonomom_mis

forvalues s=1 / 44 {
local i : word `s' of `x'

putexcel B`s'=("`i'")
reg `i' treated  if `i'!=.&balancing_test==1&curso==3, cluster(COD_CENTRO)
matrix a=e(b)
matlist a
matrix b= [a[1,1]+a[1,2], a[1,2]]
matlist b
putexcel C`s' = matrix(b)
lincom treated
matrix c= [r(se)]
*putexcel E`s' = matrix(c)
matrix d= [a[1,1]/c[1,1]]
putexcel E`s'= matrix(d)

}

local row = 1
foreach x of varlist $DESCVARS {
describe `x'
local varlabel : var label `x'
putexcel A`row' = ("`varlabel'")
local row = `row'+1
}


tabstat $DESCVARS1, stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel A1 = matrix(results), names nformat(number_d3)

tabstat $DESCVARS1 if treated==1, stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel E1 = matrix(results), names nformat(number_d3)

tabstat $DESCVARS1 if treated==0, stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel I1 = matrix(results), names nformat(number_d3)

tabstat $DESCVARS1 if treated==1&publico2==1&(stratum!=14&stratum!=15), stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel M1 = matrix(results), names nformat(number_d3)

tabstat $DESCVARS1 if treated==0&publico2==1&(stratum!=14&stratum!=15), stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel Q1 = matrix(results), names nformat(number_d3)

tabstat $DESCVARS1 if treated==1&publico2==0&(stratum!=14&stratum!=15), stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel U1 = matrix(results), names nformat(number_d3)

tabstat $DESCVARS1 if treated==0&publico2==0&(stratum!=14&stratum!=15), stat(n mean sd) save
return list
matlist r(StatTotal)
matrix results = r(StatTotal)'
matlist results
putexcel set EvaluacionCorto.xlsx, sheet(Table2_v1) modify
putexcel Y1 = matrix(results), names nformat(number_d3)

* Tex
mata: mata clear

* Test of differences
local i = 1

foreach var in $DESCVARS {
    reg `var' treated, vce(cluster COD_CENTRO)
    outreg, keep(treated)  rtitle("`: var label `var''") stats(b) ///
        noautosumm store(row`i')  starlevels(10 5 1) starloc(1)
    outreg, replay(diff) append(row`i') ctitles("",Difference ) ///
        store(diff) note("")
    local ++i
}
outreg, replay(diff)

* Summary statistics
local count: word count $DESCVARS
mat sumstat = J(`count',44,.)

local i = 1
foreach var in $DESCVARS {
    quietly: summarize `var' if treated==0
    mat sumstat[`i',1] = r(N)
    mat sumstat[`i',2] = r(mean)
    mat sumstat[`i',3] = r(sd)
    quietly: summarize `var' if treated==1
    mat sumstat[`i',4] = r(N)
    mat sumstat[`i',5] = r(mean)
    mat sumstat[`i',6] = r(sd)
    local i = `i' + 1
}
frmttable, statmat(sumstat) store(sumstat) sfmt(g,f,f,g,f,f)

*And export
cd "C:\Users\Usuario\Dropbox\JHR\replication file november\"
outreg using "Tables/Table2\Table2.tex", ///
    replay(sumstat) merge(diff) tex nocenter note("") fragment plain replace ///
    ctitles("", Control, "", "", Treatment, "", "", "" \ "", n, mean, sd, n, mean, sd, Diff) ///
    multicol(1,2,3;1,5,3) 


log close
