clear all
cap log close
set more off
cd "C:\Users\Usuario\Dropbox\JHR\replication file"

log using "C:\Users\Usuario\Dropbox\JHR\replication file november\Tables\Table3\logfile\Table3.log", replace

*****************
**** Table 3 ****
*****************

use "Datafiles\Students", clear

* Normalized score by "curso"

forvalues i=3(1)4{
sum pretest		if curso==`i'	//december
gen a=r(mean)	if curso==`i'
gen b=r(sd)		if curso==`i'
gen norm_pretest_`i'eso=(pretest-a)/b if pretest!=.&curso==`i'
replace norm_pretest_`i'eso=0 if pretest==.
drop a b
}

gen 	norm_pretest=0
replace norm_pretest=norm_pretest_3eso	if curso==3
replace norm_pretest=norm_pretest_4eso	if curso==4

gen norm_pretestmis=(pretest==.)
replace pretest=0 if norm_pretestmis==1


forvalues i=3(1)4{
sum postest		if curso==`i'	//march
gen a=r(mean)	if curso==`i'
gen b=r(sd)		if curso==`i'
gen norm_postest_`i'eso=(postest-a)/b if postest!=.&curso==`i'
drop a b
}

gen 	norm_postest=0	if postest!=.
replace norm_postest=norm_postest_3eso	if postest!=.&curso==3
replace norm_postest=norm_postest_4eso	if postest!=.&curso==4


forvalues i=3(1)4{
sum june_postest		if curso==`i'	//june
gen a=r(mean)	if curso==`i'
gen b=r(sd)		if curso==`i'
gen norm_june_postest_`i'eso=(june_postest-a)/b if june_postest!=.&curso==`i'
drop a b
}

gen 	norm_june_postest=0 if june_postest!=.
replace norm_june_postest=norm_june_postest_3eso	if june_postest!=.&curso==3
replace norm_june_postest=norm_june_postest_4eso	if june_postest!=.&curso==4



* Fraction correct
gen 	fraction_pretest=pretest/10
gen 	fraction_pretest_mis=(pretest==.)
replace fraction_pretest=0 if fraction_pretest_mis==1
gen 	fraction_postest=postest/10
gen 	fraction_june_postest=june_postest/10

label variable treated 		"Treated"

*Summary
summ norm_pretest norm_pretestmis norm_postest norm_june_postest
summ norm_pretest norm_pretestmis norm_postest norm_june_postest if treated==1
summ norm_pretest norm_pretestmis norm_postest norm_june_postest if treated==0

** PANEL A: Treated students vs controls (9th graders). March

summ fraction_postest if march_Asistencia==1&curso==3
summ fraction_postest if balanced_sample==1&curso==3

summ fraction_pretest if march_Asistencia==1&curso==3&fraction_pretest_mis==0
summ fraction_pretest if balanced_sample==1&curso==3&fraction_pretest_mis==0

* Model 1: No strata (panel no balanceado)
regress norm_postest treated norm_pretest norm_pretestmis if march_Asistencia==1&curso==3, robust cluster(COD_CENTRO)

* Model 2: Strata dummies (panel no balanceado y estratos originales)
regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if march_Asistencia==1&curso==3, robust cluster(COD_CENTRO)

* Model 3: Strata dummies (panel balanceado y estratos originales)
regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if balanced_sample==1&curso==3, robust cluster(COD_CENTRO)

* Model 4: Strata dummies (panel balanceado y estratos nuevos)
regress norm_postest treated norm_pretest stratum_c2-stratum_c16 if balanced_sample==1&curso==3, robust cluster(COD_CENTRO)

* Export tex
eststo clear
eststo:regress norm_postest treated norm_pretest norm_pretestmis if march_Asistencia==1&curso==3, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if march_Asistencia==1&curso==3, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if balanced_sample==1&curso==3, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_postest treated norm_pretest stratum_c2-stratum_c16 if balanced_sample==1&curso==3, robust cluster(COD_CENTRO)
estadd ysumm
cd "C:\Users\Usuario\Dropbox\JHR\replication file november\Tables\Table3\Tables"
esttab using "Table3A.tex", b(3) se(3) ar2(3) stats(ymean N r2_a, fmt(%9.2f %9.0g %9.2f)  labels ("Mean dependent variable" "Number of students (schools)" "Adjusted R-Squared")) star(* 0.1 ** 0.05 *** 0.01) label title(Panel A: Treated students vs controls (9th graders). March\label{Table 3}) /*
*/ mgroups(Unbalanced Balanced, pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) /*
*/ alignment(D{.}{.}{-1}) nonumbers mtitles("\shortstack{No strata \\ (1)}" "\shortstack{Strata dummies \\ (2)}" "\shortstack{Strata dummies \\ (3)}" "\shortstack{Strata dummies* \\ (4)}") /*
*/ keep(treated) /*addnote("Notes: the dependent variable is the normalized score in the March 2015 (or June 2015) test. All models include as covariate the score in the December pre-test. Models 2 and 3 include strata dummies. Model 4 merges two strata where no school assigned to treatment accepted to participate. Estimation method: OLS. The standard errors (S.E) are corrected for heteroscedasticity and arbitrary correlation at the school level.")*/ replace 


** PANEL B: Non-treated students in treated schools vs those in control schools (10th graders). March

summ fraction_postest if march_Asistencia==1&curso==4
summ fraction_postest if balanced_sample==1&curso==4

summ fraction_pretest if march_Asistencia==1&curso==4&fraction_pretest_mis==0
summ fraction_pretest if balanced_sample==1&curso==4&fraction_pretest_mis==0

* Model 1: No strata (panel no balanceado)
regress norm_postest treated norm_pretest norm_pretestmis if march_Asistencia==1&curso==4, robust cluster(COD_CENTRO)

* Model 2: Strata dummies (panel no balanceado y estratos originales)
regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if march_Asistencia==1&curso==4, robust cluster(COD_CENTRO)

* Model 3: Strata dummies (panel balanceado y estratos originales)
regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if balanced_sample==1&curso==4, robust cluster(COD_CENTRO)

* Model 4: Strata dummies (panel balanceado y estratos nuevos)
regress norm_postest treated norm_pretest stratum_c2-stratum_c16 if balanced_sample==1&curso==4, robust cluster(COD_CENTRO)

* Export tex
eststo clear
eststo:regress norm_postest treated norm_pretest norm_pretestmis if march_Asistencia==1&curso==4, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if march_Asistencia==1&curso==4, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_postest treated norm_pretest norm_pretestmis stra2-stra16 if balanced_sample==1&curso==4, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_postest treated norm_pretest stratum_c2-stratum_c16 if balanced_sample==1&curso==4, robust cluster(COD_CENTRO)
estadd ysumm

cd "C:\Users\Usuario\Dropbox\JHR\replication file november\Tables\Table3\Tables"

esttab using "Table3B.tex", b(3) se(3) ar2(3) stats(ymean N r2_a, fmt(%9.2f %9.0g %9.2f)  labels ("Mean dependent variable" "Number of students (schools)" "Adjusted R-Squared")) star(* 0.1 ** 0.05 *** 0.01) label title(Panel B: Non-treated students in treated schools vs those in control schools (10th graders). March/*\label{Table 4}*/) /*
*/ mgroups(Unbalanced Balanced, pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) /*
*/ alignment(D{.}{.}{-1}) nonumbers mtitles("\shortstack{No strata \\ (1)}" "\shortstack{Strata dummies \\ (2)}" "\shortstack{Strata dummies \\ (3)}" "\shortstack{Strata dummies* \\ (4)}") /*
*/ keep(treated) /*addnote("Notes: the dependent variable is the normalized score in the March 2015 (or June 2015) test. All models include as covariate the score in the December pre-test. Models 2 and 3 include strata dummies. Model 4 merges two strata where no school assigned to treatment accepted to participate. Estimation method: OLS. The standard errors (S.E) are corrected for heteroscedasticity and arbitrary correlation at the school level.")*/ replace 



** PANEL C: Treated students vs controls (9th graders). June

summ fraction_june_postest if june_Asistencia==1&curso==3
summ fraction_june_postest if june_Asistencia==1&curso==3&june_balanced_sample==1

summ fraction_pretest if june_Asistencia==1&curso==3&fraction_pretest_mis==0
summ fraction_pretest if june_Asistencia==1&curso==3&fraction_pretest_mis==0

* Model 1: No strata (panel no balanceado)
regress norm_june_postest treated norm_pretest norm_pretestmis if june_Asistencia==1&curso==3, robust cluster(COD_CENTRO)

* Model 2: Strata dummies (panel no balanceado y estratos originales)
regress norm_june_postest treated norm_pretest norm_pretestmis stra2-stra16 if june_Asistencia==1&curso==3, robust cluster(COD_CENTRO) 

* Model 3: Strata dummies (panel balanceado y estratos originales)
regress norm_june_postest treated norm_pretest norm_pretestmis stra2-stra16 if june_Asistencia==1&curso==3&june_balanced_sample==1, robust cluster(COD_CENTRO)

* Model 4: Strata dummies (panel balanceado y estratos nuevos)
regress norm_june_postest treated norm_pretest stratum_c2-stratum_c16 if june_Asistencia==1&curso==3&june_balanced_sample==1, robust cluster(COD_CENTRO)

* Export tex
eststo clear
eststo:regress norm_june_postest treated norm_pretest norm_pretestmis if june_Asistencia==1&curso==3, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_june_postest treated norm_pretest norm_pretestmis stra2-stra16 if june_Asistencia==1&curso==3, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_june_postest treated norm_pretest norm_pretestmis stra2-stra16 if june_Asistencia==1&curso==3&june_balanced_sample==1, robust cluster(COD_CENTRO)
estadd ysumm
eststo:regress norm_june_postest treated norm_pretest stratum_c2-stratum_c16 if june_Asistencia==1&curso==3&june_balanced_sample==1, robust cluster(COD_CENTRO)
estadd ysumm
esttab using "Table3C.tex", b(3) se(3) ar2(3) stats(ymean N r2_a, fmt(%9.2f %9.0g %9.2f)  labels ("Mean dependent variable" "Number of students (schools)" "Adjusted R-Squared")) star(* 0.1 ** 0.05 *** 0.01) label title(Panel C: Treated students vs controls (9th graders). June/*\label{Table 3}*/) /*
*/ mgroups(Unbalanced Balanced, pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) /*
*/ alignment(D{.}{.}{-1}) nonumbers mtitles("\shortstack{No strata \\ (1)}" "\shortstack{Strata dummies \\ (2)}" "\shortstack{Strata dummies \\ (3)}" "\shortstack{Strata dummies* \\ (4)}") /*
*/ keep(treated) /*addnote("Notes: the dependent variable is the normalized score in the March 2015 (or June 2015) test. All models include as covariate the score in the December pre-test. Models 2 and 3 include strata dummies. Model 4 merges two strata where no school assigned to treatment accepted to participate. Estimation method: OLS. The standard errors (S.E) are corrected for heteroscedasticity and arbitrary correlation at the school level.")*/ replace 


log close
