clear all
cap log close
set more off
*cd "X:\Dga_EI\AMicro\TRABAJO\FLIT_evaluacion_2014-2015\2020_version\"
cd "F:\BdE_11032020\FLIT_evaluacion_2014-2015\2020_version\"

log using "Logfiles\Table7+Table5A_MHT.log", replace

**********************
**** MHT: Table 7 ****
**********************

use "Datafiles\Students", clear

keep if balanced_sample==1&curso==3

** Variables **

foreach x in paga_tcasa_0 paga_ntcasa_0 trab_ocas_0 paga_negociof_0 paga_fam_0 venta_internet_0 labor_income_0 {
replace `x'=0 if `x'_mis==1 
}

* Frequency talks to parents about economics
foreach x in daily0 onceweek0 bonceweek0 nevertalk0 {
replace `x'=0 if `x'==.
}

label variable treated 		"Treated"

local dep "trab_ocas_1 venta_internet_1 paga_tcasa_1 paga_negociof_1"
local exog "treated paga_tcasa_0 paga_ntcasa_0 trab_ocas_0 paga_negociof_0 venta_internet_0 paga_tcasa_0_mis"
local strata "stratum_c2-stratum_c16"

local depA1 "daily1 onceweek1 bonceweek1 nevertalk1"
local depA2 "freq_cont1"
local exogA "treated daily0 onceweek0 nevertalk0 talk0_mis"


*preserve
keep `dep' `depA1' `depA2' `exogA' `exog' `strata' labor_income_1 labor_income_0 labor_income_0_mis idestu COD_CENTRO 
		
label var trab_ocas_1 		"Occasional jobs"
label var venta_internet_1 	"Sells things (Internet, markets)"
label var paga_tcasa_1 		"Money for tasks at home"
label var paga_negociof_1 	"Work in family business"
label var labor_income_1 	"Any source of labor income"
		
save "Datafiles\temp.dta", replace
		
*restore	
global dep_glo "`dep'"
global exog_glo "`exog'"
global strata_glo "`strata'"

global dep_gloA1 "`depA1'"
global dep_gloA2 "`depA2'"
global exog_gloA "`exogA'"

************ 0. Original Regression Table 7 *****************

foreach x in $dep_glo {
	di `"`:var lab `x''"'
	reg `x' $exog_glo $strata_glo, r cluster(COD_CENTRO)
}

foreach x in $dep_gloA1 {
	di `"`:var lab `x''"'
	reg `x' $exog_gloA $strata_glo, r cluster(COD_CENTRO)
}

foreach x in $dep_gloA2 {
	di `"`:var lab `x''"'
	oprobit `x' $exog_gloA $strata_glo, r cluster(COD_CENTRO)
}

************** 1. Original Tests *****************

// Number of replications
	
	local B = 1

// Starting replication
		
	local I = 1

	
while `I' <= `B' {
	
	di as error "`I'"
		
	qui {

		// Open dataset
		
		u "Datafiles\temp.dta", clear
		
		// Define locals
		
		local dep_var "$dep_glo"
		local exog "$exog_glo"
		local strata "$strata_glo"
		
		// Run ORIGINAL estimates	
									
		qui {
		
			*xtset ind_id time2	
			
			local count = 1

			foreach x in `dep_var' {
									
						reg `x' `exog' `strata', robust cluster(COD_CENTRO)
						gen b_or_`count'_ = _b[treated]
						gen se_or_`count'_ = _se[treated]
						local l`x' : variable label `x'
						label var b_or_`count'_ "`l`x'_treated"
						local count = `count' + 1			
						
			}		
			
			reg labor_income_1 treated labor_income_0 labor_income_0_mis `strata', robust cluster(COD_CENTRO)			
			gen b_or_5_ = _b[treated]
			gen se_or_5_ = _se[treated]
			local llabor_income_1 : variable label labor_income_1
			label var b_or_5_ "`llabor_income_1_treated"
					
			*** PANEL A: Frequency talks to parents about economics
			* Frequency talks to parents about economics: daily 
			reg daily1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_6_ = _b[treated]
			gen se_or_6_ = _se[treated]
			local ldaily1 : variable label daily1
			label var b_or_6_ "`ldaily1_6_treated"
			* Frequency talks to parents about economics: once a week
			reg onceweek1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_7_ = _b[treated]
			gen se_or_7_ = _se[treated]
			local lonceweek1 : variable label onceweek1
			label var b_or_7_ "`lonceweek1_7_treated"
			* Frequency talks to parents about economics: less than once a week
			reg bonceweek1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_8_ = _b[treated]
			gen se_or_8_ = _se[treated]
			local lbonceweek1 : variable label bonceweek1
			label var b_or_8_ "`lbonceweek1_8_treated"
			* Frequency talks to parents about economics: never  
			reg nevertalk1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_9_ = _b[treated]
			gen se_or_9_ = _se[treated]
			local lnevertalk1 : variable label nevertalk1
			label var b_or_9_ "`lnevertalk1_9_treated"
			* Frequency talks to parents about economics: daily 
			oprobit freq_cont1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_10_ = _b[treated]
			gen se_or_10_ = _se[treated]
			local lfreq_cont1 : variable label freq_cont1
			label var b_or_10_ "`lfreq_cont1_10_treated"		
			
		}
									
	}
	
	// Copy variable labels
		
	foreach v of var * {		
		local lab`v' : variable label `v'								
	}
	
	// Generate dataset of estimates and standard errors
				
	collapse b_or_* se_or_*
	gen i = 1
			
	// Paste variable labels
					
	foreach v of var * { 
		label var `v' "`lab`v''" 				
	} 
	
	// Save dataset
	
	gen iter = `I'

	if `I' == 1 {	
		sort i
		save "Datafiles\Table7+Table5A_or.dta", replace
	}
				
	local I= `I' + 1
		
} 	
	
	
********************* 2. Bootstrap ***********************

 	set seed 13052019			// set seeds for replicability of results

	// Number of replications
	
	local B =  1000

	// Starting replication
		
	local I = 1
			
while `I' <= `B' {

	*sleep 500				// if code breaks down because replications occur too quickly set the sleep command to slow it down 
	
	di as error "`I'"
		
	qui {

		// Open dataset
			
		use "Datafiles\temp.dta", clear
		
		// Define locals
		
		local dep_var "$dep_glo"
		local exog "$exog_glo"
		local strata "$strata_glo"
						
		// Bootstrap resampling	(clustered)
			
		bsample , cl(COD_CENTRO)
					
		// Run BOOTSTRAP estimates	
		
		qui {
			
			// Create new id for individual (otherwise, due to resampling, I would have duplicated observations in the panel)
			
			bys idestu : gen ord = _n
			egen idestu_bs = group(idestu ord)
			
			*duplicates report ind_id_bs time
			*tab time
				
			local count = 1

			foreach x in `dep_var' {
											
						reg `x' `exog' `strata', robust cluster(COD_CENTRO)		
						gen b_`count'_ = _b[treated]
						gen se_`count'_ = _se[treated]
						local l`x' : variable label `x'
						label var b_`count'_ "`l`x'treated"
						local count = `count' + 1
					
			}	
			
			reg labor_income_1 treated labor_income_0 labor_income_0_mis `strata', robust cluster(COD_CENTRO)			
			gen b_5_ = _b[treated]
			gen se_5_ = _se[treated]
			local llabor_income_1 : variable label labor_income_1
			label var b_5_ "`llabor_income_1_treated"
		
			*** PANEL A: Frequency talks to parents about economics
			* Frequency talks to parents about economics: daily 
			reg daily1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_6_ = _b[treated]
			gen se_6_ = _se[treated]
			local ldaily1 : variable label daily1
			label var b_6_ "`ldaily1_6_treated"
			* Frequency talks to parents about economics: once a week
			reg onceweek1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_7_ = _b[treated]
			gen se_7_ = _se[treated]
			local lonceweek1 : variable label onceweek1
			label var b_7_ "`lonceweek1_7_treated"
			* Frequency talks to parents about economics: less than once a week
			reg bonceweek1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_8_ = _b[treated]
			gen se_8_ = _se[treated]
			local lbonceweek1 : variable label bonceweek1
			label var b_8_ "`lbonceweek1_8_treated"
			* Frequency talks to parents about economics: never  
			reg nevertalk1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_9_ = _b[treated]
			gen se_9_ = _se[treated]
			local lnevertalk1 : variable label nevertalk1
			label var b_9_ "`lnevertalk1_9_treated"
			* Frequency talks to parents about economics: daily 
			oprobit freq_cont1 treated daily0 onceweek0 nevertalk0 talk0_mis stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_10_ = _b[treated]
			gen se_10_ = _se[treated]
			local lfreq_cont1 : variable label freq_cont1
			label var b_10_ "`lfreq_cont1_10_treated"
			
		}
				
	}
		
	// Copy variable labels
		
	foreach v of var * {		
		local lab`v' : variable label `v'							
	}
		
	// Generate dataset of estimates and standard errors
				
	collapse b_* se_*
	gen i = 1
	
	// Paste variable labels
					
	foreach v of var * { 
		label var `v' "`lab`v''" 				
	} 
				
	// Save dataset

	gen iter = `I'
				
	if `I' == 1 {				
		save "Datafiles\Table7+Table5A_bs.dta", replace			
	}

	if `I' > 1 {			
		append using "Datafiles\Table7+Table5A_bs.dta"
		save "Datafiles\Table7+Table5A_bs.dta", replace				
	}	
					
	local I = `I' + 1
		
} 	
	

* preserve
	
use "Datafiles\Table7+Table5A_bs.dta", clear
		
forvalues i=1(1)10 {
	foreach x in se_`i'_ b_`i'_{
		sum `x', d
	}
}
		
sort i
merge i using "Datafiles\Table7+Table5A_or.dta"	
 

********************* 3. Two-sided test ***********************
* Total number of hypothesis to test (in the 1st step) 
	
	local S = 0	
	local numlist ""
	
	foreach var of varlist b_or_* {	
		local S = `S' + 1
		local numlist "`numlist' `S'"			
	}	
	
* Generate t-statistics for regressions 
	
	foreach x of numlist `numlist' {	
		gen tstat_`x' 	 = abs(b_or_`x'_ / se_or_`x'_)
		gen tstat_bs_`x' = abs((b_`x'_ - b_or_`x'_) / se_`x'_)		// see remark 3.4 in Romano and Wolf (p. 1251)			
		/*Generate a dummy to count the number of times the test statistic of the bootstrap is greater or equal to 1.96 */
		gen dumtest_bs_`x'=(abs(tstat_bs_`x')>=1.96)
		gen dumtest_`x'=(abs(tstat_`x')>=1.96)
		}
	/*
	foreach x in dumtest_bs_1 dumtest_bs_2 dumtest_bs_3 dumtest_bs_4 dumtest_bs_5{
	sum `x'
	}
		
	foreach x in dumtest_1 dumtest_2 dumtest_3 dumtest_4 dumtest_5{
	sum `x'
	}*/
* Generate list of statistics to test and list of corresponding numerical indeces 
	
	foreach var of varlist tstat_bs_* {			
		local vl "`vl' `var'"			
	}	

	
*** MHT with different confidence levels
				
foreach A of numlist 90 95 99 {
			
	preserve
		
		local Z = `S'
		local NR = `S' 		/* Initial number of hypothesis to test*/
		local J = 1			/* J is an index for the iteration */
				
		local vl`J' `vl'
		local vl_num`J' `numlist'
					
		while `NR' > 0 { 
											
			qui {
								
				* Highest tstat by iteration (step 4.a - alg 2.4)
									
					egen maxm`J' = rowmax(`vl`J'')
														
				* Critical value as the Ath percentile of the max tstats distribution (step 4.b - alg 2.4 - (1-a) = A%)
	
					egen d_hat`J' = pctile(maxm`J'), p(`A')			/* TRY LOW PERCENTILE TO HAVE REJ */
			
				* Reject S if tsat > critical value (step 3 - alg 4.1)
							
					foreach x in `vl_num`J'' {
		
						gen rej`J'_`x' = (abs(tstat_`x') > d_hat`J')
						local answer = rej`J'_`x'

					}

			}
			
			*qui log using "Schooling_Paper/Analysis/Estimates/IV_FE/Robustness/Romano_Wolf/MHT_twosided_$title$.log", append
			
			di as error _n "Confidence level = `A'" _n "Iteration J = `J'"
					
			foreach x in `vl_num`J'' {
					
				local answer = rej`J'_`x'
				local lab: variable label b_`x'_
				dis "Coefficient `lab' `answer'" 	
						
			}	
			
			qui {
			
				// Total number of rejected hypothesis
						
					egen rejtot = rowtotal(rej`J'*)
					local NR = rejtot
					drop rejtot
					
			}		
		
			di "Total number of tested hypothesis `Z'"
			di "Total number of rejected hypothesis `NR'"
			
			di as text "------------------------------------------------------------"
			
			*qui log close
			
			local Z = `Z' - `NR'
				
			// Exclude rejected hypothesis from next steps of iteration (redefine lists of statistics to be tested)
					
				local K = `J' + 1
				local vl_num`K' ""
				local vl`K' ""
					
				foreach x in `vl_num`J'' {
														
					if rej`J'_`x' == 0 {
						
						local vl_num`K' "`vl_num`K'' `x'"
						local vl`K' "`vl`K'' tstat_bs_`x'"
						
					}	
						
				}

				local J = `J' + 1
				
		}
		
	save "Datafiles\Table7+Table5A_twosided.dta", replace	
	restore

}
 
*restore

 
********** 4. ADJUSTED P-VALUES Two-sided test (ROMANO & WOLF, 2016) ***********

* Load Romano and Wolf dataset

	use "Datafiles\Table7+Table5A_twosided.dta", clear

* Total number of hypothesis to test (in the 1st step) 
	
	local S = 0	
	local numlist ""
	
	foreach var of varlist b_or_* {	
		local S = `S' + 1
		local numlist "`numlist' `S'"			
	}		
	
	drop i _merge rej* maxm? d_hat*
	order iter, first
	order b_or_* se_or_* b_?_ b_??_ se_?_ se_??_, after(iter)
	order tstat_? tstat_??, after(se_`S'_)
	sort iter
		
* Order hypothesis from most to least significant (Section 3, RW, 2016)

	reshape long tstat_, i(iter) j(ord)

	gsort iter -tstat_
	bys iter : gen n = _n
	order n, after(iter)
	
	/*label drop nprog_2*/
	reshape wide tstat_ ord, i(iter) j(n)
			
	local i = 0
	foreach x of varlist ord? ord?? {
		local ++i
		qui sum `x'
		local k = r(mean)
		gen tstat_bs_r`i' = tstat_bs_`k'
		if `i' == 1 {
			order tstat_bs_r`i' tstat_bs_`k', after(se_`S')
		}
		else {
			order tstat_bs_r`i', after(tstat_bs_r`i0')
			order tstat_bs_`k', after(tstat_bs_`k0')
		}
		local i0 = `i'
		local k0 = `k'
	}	
	
* Compute maxima for test statistics (Section 3, RW, 2016)
	
	local i = 0	
	foreach x of varlist ord? ord?? {
		local ++i
		qui sum `x'	
		local k = r(mean)
		egen max`i' = rowmax(tstat_bs_r`i'-tstat_bs_r`S')
	}	

* Compute adjusted p-values (Section 4, RW, 2016)

	qui sum iter
	local M = r(max)

	forvalues i = 1 / `S' {
		qui sum ord`i'
		local s = r(mean)
		if `i' == 1 {
			egen padj_r`i' = total(max`i' >= tstat_`i')
			replace padj_r`i' = (padj_r`i' + 1) / (`M' + 1)
			gen padj_`s' = padj_r`i'
		}
		else {
			egen padj_r`i' = total(max`i' >= tstat_`i')
			replace padj_r`i' = (padj_r`i' + 1) / (`M' + 1)
			replace padj_r`i' = max(padj_r`i', padj_r`i0')
			gen padj_`s' = padj_r`i'		
			order padj_r`i', after(padj_r`i0')
		}
		local i0 = `i'
	}	
	
* Display results

*qui log using "Logfiles\Table7+Table5A_MHT_adjpvalues_twosided.log", replace

	forvalues i = 1 / `S' {
		local lab: variable label b_`i'_
		qui sum padj_`i'
		local p = round(r(mean), .001)
		dis "Coefficient: `lab', adjusted p value = `p'" 	
						
	}		
	
	
*qui log close	

cap log close

