clear all
cap log close
set more off
cd "F:\BdE_11032020\FLIT_evaluacion_2014-2015\2020_version\"

log using "Logfiles\Table4B_MHT.log", replace

**********************
**** MHT: Table 4B ***
**********************

use "Datafiles\Students", clear

keep if balanced_sample==1&curso==3

** Variables **

* Frequency talks to parents about economics
foreach x in daily0 onceweek0 bonceweek0 nevertalk0 {
replace `x'=0 if `x'==.
}

* Hypothetical saving choices

** H1 (100 today, 120 in three weeks) 
set seed 999
gen u = uniform()

replace dec100_120=0 if december_CA_P11A==3 & u>=0.5
replace dec100_120=1 if december_CA_P11A==3 & u<0.5
label define dec100_120 1 "100 euros today" 0 "120 in three weeks", replace

replace dec100_120_mis=0 if december_CA_P11A==3		//now, dec100_120_mis=1 only when december_CA_P11A==.
replace dec100_120=0 if dec100_120_mis==1

label define mar100_120 1 "100 euros today" 0 "120 in three weeks", replace

** H2 (100 today, 120 in six weeks) (March)
label define mar100_120_2 1 "100 euros today" 0 "120 in six weeks", replace

** H3 (100 today, 150 in three weeks) 
replace dec100_150=0 if december_CA_P11B==3 & u>=0.5
replace dec100_150=1 if december_CA_P11B==3 & u<0.5
label define dec100_150 1 "100 euros today" 0 "150 in three weeks", replace

replace dec100_150_mis=0 if december_CA_P11B==3		//now, dec100_150_mis=1 only when december_CA_P11B==.
replace dec100_150=0 if dec100_150_mis==1

label define mar100_150 1 "100 euros today" 0 "150 in three weeks", replace

** H4 (100 today, 180 in three weeks) 
replace dec100_180=0 if december_CA_P11C==3 & u>=0.5
replace dec100_180=1 if december_CA_P11C==3 & u<0.5
label define dec100_180 1 "100 euros today" 0 "180 in three weeks", replace

replace dec100_180_mis=0 if december_CA_P11C==3		//now, dec100_180_mis=1 only when december_CA_P11C==.
replace dec100_180=0 if dec100_180_mis==1

label define mar100_180 1 "100 euros today" 0 "180 in three weeks", replace
label variable treated 		"Treated"

save "Datafiles\append1.dta",replace

** Pooling Data **

use			 "Datafiles\append1.dta"
gen dum1=1
append using "Datafiles\append1.dta"
replace dum1=2 if dum1==.
append using "Datafiles\append1.dta"
replace dum1=3 if dum1==.
append using "Datafiles\append1.dta"
replace dum1=4 if dum1==.

*generar las elecciones DICIEMBRE
gen		eleccion_dec= dec100_120 if dum1==1
replace eleccion_dec= dec100_150 if dum1==2
replace eleccion_dec= dec100_180 if dum1==3

*generar las elecciones MARZO
gen		eleccion_mar= mar100_120 	if dum1==1
replace eleccion_mar= mar100_150 	if dum1==2
replace eleccion_mar= mar100_180 	if dum1==3
replace eleccion_mar= mar100_120_2 	if dum1==4

* Dummies de eleccion
gen dum_rd20	=(dum1==1)
gen dum_rd50	=(dum1==2)
gen dum_rd80	=(dum1==3)
gen dum_rd20_2	=(dum1==4)

* Nos quedamos con 1 de las 4 repeticiones de los datos para estas variables dependientes:
foreach x in daily1 onceweek1 bonceweek1 nevertalk1 freq_cont1 mar100_120 mar100_120_2 mar100_150 mar100_180 {
rename `x' m`x'
gen `x'=. 
replace `x'=m`x' if dum1==1
}


save "Datafiles\appended.dta", replace

local depB1 "mar100_120 mar100_120_2 mar100_150 mar100_180"
local depB2 "eleccion_mar"
local exogB1 "treated dec100_120 dec100_120_mis dec100_150 dec100_180"
local exogB2 "treated dec100_120 dec100_120_mis dec100_150 dec100_180 dum_rd20 dum_rd50 dum_rd80"
local strata "stratum_c2-stratum_c16"

preserve

keep `depB1' `depB2' `exogB1' `exogB2' `strata' dum1 idestu COD_CENTRO 

label var mar100_120 	"100 today, 120 in three weeks"
label var mar100_120_2 	"100 today, 120 in six weeks"
label var mar100_150 	"100 today, 150 in three weeks"
label var mar100_180 	"100 today, 180 in three weeks"
label var eleccion_mar 	"Earlier Choice (Pooled)"

save "Datafiles\temp.dta", replace
		
restore	

global dep_gloB1 "`depB1'"
global dep_gloB2 "`depB2'"
global exog_gloB1 "`exogB1'"
global exog_gloB2 "`exogB2'"
global strata_glo "`strata'"


************ 0. Original Regression Table 5B *****************

foreach x in $dep_gloB1 {
	di `"`:var lab `x''"'
	reg `x' $exog_gloB1 $strata_glo, r cluster(COD_CENTRO)
}

foreach x in $dep_gloB2 {
	di `"`:var lab `x''"'
	reg `x' $exog_gloB2 $strata_glo, r cluster(COD_CENTRO)
}

/************** 1. Original Tests *****************/

// Number of replications
	
	local B = 1

// Starting replication
		
	local I = 1

	
while `I' <= `B' {
	
	di as error "`I'"
		
	qui {

		// Open dataset
		
		use "Datafiles\temp.dta", clear
			
		// Run ORIGINAL estimates	
									
		qui {
		
		
			*** PANEL B: Hypothetical saving choices, prefers euros today vs euros in 3-6 weeks
			* H1 (100 today, 120 in three weeks)
			reg mar100_120 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_1_ = _b[treated]
			gen se_or_1_ = _se[treated]
			local lmar100_120 : variable label mar100_120
			label var b_or_1_ "`lmar100_120_1_treated"		
			* H2 (100 today, 120 in six weeks)
			reg mar100_120_2 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_2_ = _b[treated]
			gen se_or_2_ = _se[treated]
			local lmar100_120_2 : variable label mar100_120_2
			label var b_or_2_ "`lmar100_120_2_2_treated"
			* H3 (100 today, 150 in three weeks)
			reg mar100_150 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_3_ = _b[treated]
			gen se_or_3_ = _se[treated]
			local lmar100_150 : variable label mar100_150
			label var b_or_3_ "`lmar100_150_3_treated"	
			* H4 (100 today, 180 in three weeks)
			reg mar100_180 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_4_ = _b[treated]
			gen se_or_4_ = _se[treated]
			local lmar100_180 : variable label mar100_180
			label var b_or_4_ "`lmar100_180_4_treated"
			* Earlier Choice (Pooled): 
			reg eleccion_mar treated dec100_120 dec100_120_mis dec100_150 dec100_180 dum_rd20 dum_rd50 dum_rd80 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_or_5_ = _b[treated]
			gen se_or_5_ = _se[treated]
			local leleccion_mar : variable label eleccion_mar
			label var b_or_5_ "`leleccion_mar_5_treated"
	
			
		}
									
	}
	
	// Copy variable labels
		
	foreach v of var * {		
		local lab`v' : variable label `v'								
	}
	
	// Generate dataset of estimates and standard errors
				
	collapse b_or_* se_or_*
	gen i = 1
			
	// Paste variable labels
					
	foreach v of var * { 
		label var `v' "`lab`v''" 				
	} 
	
	// Save dataset
	
	gen iter = `I'

	if `I' == 1 {	
		sort i
		save "Datafiles\Table4B_or.dta", replace
	}
				
	local I= `I' + 1
		
} 	
	
	
********************* 2. Bootstrap **********************

 	set seed 13052019			// set seeds for replicability of results

	// Number of replications
	
	local B =  1000

	// Starting replication
		
	local I = 1
			
while `I' <= `B' {

	*sleep 500				// if code breaks down because replications occur too quickly set the sleep command to slow it down 
	
	di as error "`I'"
		
	qui {

		// Open dataset
			
		use "Datafiles\temp.dta", clear
		
				
		// Bootstrap resampling	(clustered)
			
		bsample , cl(COD_CENTRO)
					
		// Run BOOTSTRAP estimates	
		
		qui {
			
			// Create new id for individual (otherwise, due to resampling, I would have duplicate observations in the panel)
			
			bys idestu : gen ord = _n
			egen idestu_bs = group(idestu ord)
			
			
			*** PANEL B: Hypothetical saving choices, prefers euros today vs euros in 3-6 weeks
			* H1 (100 today, 120 in three weeks)
			reg mar100_120 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_1_ = _b[treated]
			gen se_1_ = _se[treated]
			local lmar100_120 : variable label mar100_120
			label var b_1_ "`lmar100_120_1_treated"		
			* H2 (100 today, 120 in six weeks)
			reg mar100_120_2 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_2_ = _b[treated]
			gen se_2_ = _se[treated]
			local lmar100_120_2 : variable label mar100_120_2
			label var b_2_ "`lmar100_120_2_2_treated"
			* H3 (100 today, 150 in three weeks)
			reg mar100_150 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_3_ = _b[treated]
			gen se_3_ = _se[treated]
			local lmar100_150 : variable label mar100_150
			label var b_3_ "`lmar100_150_3_treated"	
			* H4 (100 today, 180 in three weeks)
			reg mar100_180 treated dec100_120 dec100_120_mis dec100_150 dec100_180 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_4_ = _b[treated]
			gen se_4_ = _se[treated]
			local lmar100_180 : variable label mar100_180
			label var b_4_ "`lmar100_180_4_treated"
			* Earlier Choice (Pooled): 
			reg eleccion_mar treated dec100_120 dec100_120_mis dec100_150 dec100_180 dum_rd20 dum_rd50 dum_rd80 stratum_c2-stratum_c16, r cluster(COD_CENTRO)
			gen b_5_ = _b[treated]
			gen se_5_ = _se[treated]
			local leleccion_mar : variable label eleccion_mar
			label var b_5_ "`leleccion_mar_5_treated"
			
		
		}
				
	}
		
	// Copy variable labels
		
	foreach v of var * {		
		local lab`v' : variable label `v'							
	}
		
	// Generate dataset of estimates and standard errors
				
	collapse b_* se_*
	gen i = 1
	
	// Paste variable labels
					
	foreach v of var * { 
		label var `v' "`lab`v''" 				
	} 
				
	// Save dataset

	gen iter = `I'
				
	if `I' == 1 {				
		save "Datafiles\Table4B_bs.dta", replace			
	}

	if `I' > 1 {			
		append using "Datafiles\Table4B_bs.dta"
		save "Datafiles\Table4B_bs.dta", replace				
	}	
					
	local I = `I' + 1
		
} 	
	
 
 
* preserve
	
use "Datafiles\Table4B_bs.dta", clear
		
forvalues i=1(1)5 {
	foreach x in se_`i'_ b_`i'_{
		sum `x', d
	}
}
		
sort i
merge i using "Datafiles\Table4B_or.dta"	
 

********************* 3. Two-sided test ***********************
* Total number of hypothesis to test (in the 1st step) 
	
	local S = 0	
	local numlist ""
	
	foreach var of varlist b_or_* {	
		local S = `S' + 1
		local numlist "`numlist' `S'"			
	}	
	
* Generate t-statistics for regressions 
	
	foreach x of numlist `numlist' {	
		gen tstat_`x' 	 = abs(b_or_`x'_ / se_or_`x'_)
		gen tstat_bs_`x' = abs((b_`x'_ - b_or_`x'_) / se_`x'_)		// see remark 3.4 in Romano and Wolf (p. 1251)			
		/*Generate a dummy to count the number of times the test statistic of the bootstrap is greater or equal to 1.96 */
		gen dumtest_bs_`x'=(abs(tstat_bs_`x')>=1.96)
		gen dumtest_`x'=(abs(tstat_`x')>=1.96)
		}
	
	forvalues i=1(1)5 {
		foreach x in dumtest_bs_`i' dumtest_`i' {
			sum `x'
		}
	}
	
* Generate list of statistics to test and list of corresponding numerical indeces 
	
	foreach var of varlist tstat_bs_* {			
		local vl "`vl' `var'"			
	}	

	
*** MHT WITH DIFFERENT LEVELS OF CONFIDENCE

				
foreach A of numlist 90 95 99 {
			
	preserve
		
		local Z = `S'
		local NR = `S' 		/* Initial number of hypothesis to test*/
		local J = 1			/* J is an index for the iteration */
				
		local vl`J' `vl'
		local vl_num`J' `numlist'
					
		while `NR' > 0 { 
											
			qui {
								
				* Highest tstat by iteration (step 4.a - alg 2.4)
									
					egen maxm`J' = rowmax(`vl`J'')
														
				* Critical value as the Ath percentile of the max tstats distribution (step 4.b - alg 2.4 - (1-a) = A%)
	
					egen d_hat`J' = pctile(maxm`J'), p(`A')			/* TRY LOW PERCENTILE TO HAVE REJ */
			
				* Reject S if tsat > critical value (step 3 - alg 4.1)
							
					foreach x in `vl_num`J'' {
		
						gen rej`J'_`x' = (abs(tstat_`x') > d_hat`J')
						local answer = rej`J'_`x'

					}

			}
			
			*qui log using "Schooling_Paper/Analysis/Estimates/IV_FE/Robustness/Romano_Wolf/MHT_twosided_$title$.log", append
			
			di as error _n "Confidence level = `A'" _n "Iteration J = `J'"
					
			foreach x in `vl_num`J'' {
					
				local answer = rej`J'_`x'
				local lab: variable label b_`x'_
				dis "Coefficient `lab' `answer'" 	
						
			}	
			
			qui {
			
				// Total number of rejected hypothesis
						
					egen rejtot = rowtotal(rej`J'*)
					local NR = rejtot
					drop rejtot
					
			}		
		
			di "Total number of tested hypothesis `Z'"
			di "Total number of rejected hypothesis `NR'"
			
			di as text "------------------------------------------------------------"
			
			*qui log close
			
			local Z = `Z' - `NR'
				
			// Exclude rejected hypothesis from next steps of iteration (redefine lists of statistics to be tested)
					
				local K = `J' + 1
				local vl_num`K' ""
				local vl`K' ""
					
				foreach x in `vl_num`J'' {
														
					if rej`J'_`x' == 0 {
						
						local vl_num`K' "`vl_num`K'' `x'"
						local vl`K' "`vl`K'' tstat_bs_`x'"
						
					}	
						
				}

				local J = `J' + 1
				
		}
		
	save "Datafiles\Table4B_twosided.dta", replace	
	restore

}
 
  
 *restore


 
 
 /********** 4. ADJUSTED P-VALUES Two-sided test (ROMANO & WOLF, 2016) ***********/

* Load Romano and Wolf dataset

	use "Datafiles\Table4B_twosided.dta", clear

* Total number of hypothesis to test (in the 1st step) 
	
	local S = 0	
	local numlist ""
	
	foreach var of varlist b_or_* {	
		local S = `S' + 1
		local numlist "`numlist' `S'"			
	}		
	
	drop i _merge rej* maxm? d_hat*
	order iter, first
	order b_or_* se_or_* b_?_ /*b_??_*/ se_?_ /*se_??_*/, after(iter)
	order tstat_? /*tstat_??*/, after(se_`S'_)
	sort iter
		
* Order hypothesis from most to least significant (Section 3, RW, 2016)

	reshape long tstat_, i(iter) j(ord)

	gsort iter -tstat_
	bys iter : gen n = _n
	order n, after(iter)
	
	/*label drop nprog_2*/
	reshape wide tstat_ ord, i(iter) j(n)
			
	local i = 0
	foreach x of varlist ord? /*ord??*/ {
		local ++i
		qui sum `x'
		local k = r(mean)
		gen tstat_bs_r`i' = tstat_bs_`k'
		if `i' == 1 {
			order tstat_bs_r`i' tstat_bs_`k', after(se_`S')
		}
		else {
			order tstat_bs_r`i', after(tstat_bs_r`i0')
			order tstat_bs_`k', after(tstat_bs_`k0')
		}
		local i0 = `i'
		local k0 = `k'
	}	
	
* Compute maxima for test statistics (Section 3, RW, 2016)
	
	local i = 0	
	foreach x of varlist ord? /*ord??*/ {
		local ++i
		qui sum `x'	
		local k = r(mean)
		egen max`i' = rowmax(tstat_bs_r`i'-tstat_bs_r`S')
	}	

* Compute adjusted p-values (Section 4, RW, 2016)

	qui sum iter
	local M = r(max)

	forvalues i = 1 / `S' {
		qui sum ord`i'
		local s = r(mean)
		if `i' == 1 {
			egen padj_r`i' = total(max`i' >= tstat_`i')
			replace padj_r`i' = (padj_r`i' + 1) / (`M' + 1)
			gen padj_`s' = padj_r`i'
		}
		else {
			egen padj_r`i' = total(max`i' >= tstat_`i')
			replace padj_r`i' = (padj_r`i' + 1) / (`M' + 1)
			replace padj_r`i' = max(padj_r`i', padj_r`i0')
			gen padj_`s' = padj_r`i'		
			order padj_r`i', after(padj_r`i0')
		}
		local i0 = `i'
	}	
	
* Display results

*qui log using "Logfiles\MHT_adjpvalues_twosided.log", replace

	forvalues i = 1 / `S' {
		local lab: variable label b_`i'_
		qui sum padj_`i'
		local p = round(r(mean), .001)
		dis "Coefficient: `lab', adjusted p value = `p'" 	
						
	}		
	
	
*qui log close	


cap log close

