clear all
cap log close
set more off

cd "C:\Trabajo\new_projects\FInancial-literacy-eval 2014-2015\FpT corto\evaluation2015_ana"

log using "Logfiles\comment3_implementation\Table6A_nonpublic_reweight.log", replace

*****************
**** Table 6A ****
*****************

use "Datafiles\Students", clear

** Variables **

foreach x in daily0 onceweek0 bonceweek0 nevertalk0 labor_income_0 labor_outside_0 labor_inside_0 {
replace `x'=0 if `x'==.
}

gen treated_public=publico2*treated

gen notrabajap = 1 if other_labp==1
gen E_drop16 = 1 if E_dropA==16
gen E_drop20 = 1 if E_dropA==20
gen E_drop22 = 1 if E_dropA==22

label variable foreign 			"Foreign born"
label variable repetidores 		"Older than normal progression"
label variable autonomop 		"Father is self-employed"
label variable trabajaempp 		"Father works as an employee"
label variable notrabajap 		"Father does not work"
label variable E_drop16 		"Expects to leave at 16"
label variable E_drop18 		"Expects to finish at most HS academic track"
label variable E_drop20 		"Expects to finish at most HS vocational training"
label variable E_drop22 		"Expects to finish college"
label variable treated 			"Treated"
label variable freq_cont1		"Talks to parents about economics"
label variable labor_inside_1 	"Money from chores at home/family business	"
label variable labor_outside_1 	"Money from occasional jobs outside home"
label variable labor_income_1 	"Any source of income"

* Normalized score by "curso"

sum pretest
replace pretest=pretest/10		//pasar las notas a fracción
sum pretest
sum postest
replace postest=postest/10
sum postest
sum june_postest
replace june_postest=june_postest/10
sum june_postest

forvalues i=3(1)4{
sum pretest		if curso==`i'	//december
gen a=r(mean)	if curso==`i'
gen b=r(sd)		if curso==`i'
gen norm_pretest_`i'eso=(pretest-a)/b if pretest!=.&curso==`i'
replace norm_pretest_`i'eso=0 if pretest==.
drop a b
}

gen 	norm_pretest=0
replace norm_pretest=norm_pretest_3eso	if curso==3
replace norm_pretest=norm_pretest_4eso	if curso==4

gen norm_pretestmis=(pretest==.)
replace pretest=0 if norm_pretestmis==1

forvalues i=3(1)4{
sum postest		if curso==`i'	//march
gen a=r(mean)	if curso==`i'
gen b=r(sd)		if curso==`i'
gen norm_postest_`i'eso=(postest-a)/b if postest!=.&curso==`i'
drop a b
}

gen 	norm_postest=0	if postest!=.
replace norm_postest=norm_postest_3eso	if postest!=.&curso==3
replace norm_postest=norm_postest_4eso	if postest!=.&curso==4


forvalues i=3(1)4{
sum june_postest		if curso==`i'	//june
gen a=r(mean)	if curso==`i'
gen b=r(sd)		if curso==`i'
gen norm_june_postest_`i'eso=(june_postest-a)/b if june_postest!=.&curso==`i'
drop a b
}

gen 	norm_june_postest=0 if june_postest!=.
replace norm_june_postest=norm_june_postest_3eso	if june_postest!=.&curso==3
replace norm_june_postest=norm_june_postest_4eso	if june_postest!=.&curso==4

label variable norm_postest	"Standardized test score"

* Hypothetical saving choices

** H1 (100 today, 120 in three weeks) 
set seed 999
gen u = uniform()

replace dec100_120=0 if december_CA_P11A==3 & u>=0.5
replace dec100_120=1 if december_CA_P11A==3 & u<0.5
label define dec100_120 1 "100 euros today" 0 "120 in three weeks", replace

replace dec100_120_mis=0 if december_CA_P11A==3		//now, dec100_120_mis=1 only when december_CA_P11A==.
replace dec100_120=0 if dec100_120_mis==1

label define mar100_120 1 "100 euros today" 0 "120 in three weeks", replace

** H2 (100 today, 120 in six weeks) (March)
gen mar100_120_2=0
replace mar100_120_2=0 if march_CA_C12==3 & u>=0.5
replace mar100_120_2=1 if march_CA_C12==3 & u<0.5

label define mar100_120_2 1 "100 euros today" 0 "120 in six weeks", replace

** H3 (100 today, 150 in three weeks) 
replace dec100_150=0 if december_CA_P11B==3 & u>=0.5
replace dec100_150=1 if december_CA_P11B==3 & u<0.5
label define dec100_150 1 "100 euros today" 0 "150 in three weeks", replace

replace dec100_150_mis=0 if december_CA_P11B==3		//now, dec100_150_mis=1 only when december_CA_P11B==.
replace dec100_150=0 if dec100_150_mis==1

label define mar100_150 1 "100 euros today" 0 "150 in three weeks", replace

** H4 (100 today, 180 in three weeks) 
replace dec100_180=0 if december_CA_P11C==3 & u>=0.5
replace dec100_180=1 if december_CA_P11C==3 & u<0.5
label define dec100_180 1 "100 euros today" 0 "180 in three weeks", replace

replace dec100_180_mis=0 if december_CA_P11C==3		//now, dec100_180_mis=1 only when december_CA_P11C==.
replace dec100_180=0 if dec100_180_mis==1

label define mar100_180 1 "100 euros today" 0 "180 in three weeks", replace
label variable treated 		"Treated"



global stratumc_public stratum_c4 stratum_c7 stratum_c9 stratum_c11 stratum_c16
global stratumc_concpri stratum_c5 stratum_c6 stratum_c10 stratum_c12 stratum_c13

**	B.1. Score in financial knowledge tests
keep if march_Asistencia==1 
keep if december_Asistencia==1
keep if curso==3
*** 1. Standardized test score
* Public 
reg norm_postest treated norm_pretest norm_pretestmis stratum_c2-stratum_c16 if publico2==1, robust cluster(COD_CENTRO)
* Non-public
reg norm_postest treated norm_pretest norm_pretestmis stratum_c2-stratum_c16 if publico2==0, robust cluster(COD_CENTRO)
* Test: Equality of coefficients
reg norm_postest treated treated_public norm_pretest stratum_c2-stratum_c16 , cluster(COD_CENTRO)
save "Datafiles\temp.dta", replace


*** 2. 3. 4. Fraction with less than 25%, 35%, 50% questions correct (d25, d35, d50)
* Public
gen n=_n
gen index=(n/100)
gen cdfT=.
gen cdfC=.
qui compress
local i=1
while `i'<=100 {
	gen d`i'=(postest<=((`i'/100))) 
	sum d`i'
	reg d`i' treated norm_pretest norm_pretestmis stratum_c2-stratum_c16 if curso==3 & publico2==1, cluster(COD_CENTRO)
	replace cdfT=_b[_cons] + _b[treated] if _n==`i'
	replace cdfC=_b[_cons] if _n==`i'
	drop d`i'
	qui compress
local i=`i'+1
}


keep if cdfT!=.
keep n index cdf*
drop if index>10
sort n
sc cdfT cdfC index, c(l l) title("CDF of March scores -public") xtitle("Percentage of correct answers ")  ytitle("Cumulative percentage of the sample") /*
*/ msymbol(i i) lwidth(thick thick) lcolor(black gray) lpattern(solid shortdash) /*
*/legend(label(1 "Treated") label(2 "Control") rows(2))

graph save Graph "Logfiles\graphfiles\cdfmarzo3esom1_public.gph", replace

graph export "Logfiles\graphfiles\cdfmarzo3esom1_public.eps", as(eps) preview(on) replace

use "Datafiles\temp.dta", replace

keep if march_Asistencia==1 
keep if december_Asistencia==1
keep if curso==3

drop if stratum==14|stratum==15 /*The sample excludes one stratum that mixes 1 public and 2 non-public centers. 
								That stratum originally grouped high schools who intended to teach the course
								to 7th or 8th graders (ESO1 or ESO2).*/
gen n=_n
gen index=(n/100)
gen cdfT=.
gen cdfC=.
qui compress
local i=1
while `i'<=100 {
	gen d`i'=(postest<=((`i'/100))) 
	sum d`i'
	reg d`i' treated norm_pretest norm_pretestmis stratum_c2-stratum_c16 if publico2==0, cluster(COD_CENTRO)
	replace cdfT=_b[_cons] + _b[treated] if _n==`i'
	replace cdfC=_b[_cons] if _n==`i'
	drop d`i'
	qui compress
local i=`i'+1
}

keep if cdfT!=.
keep n index cdf*
drop if index>10
sort n
sc cdfT cdfC index, c(l l) title("CDF of March scores -nonpublic") xtitle("Percentage of correct answers ")  ytitle("Cumulative percentage of the sample") /*
*/ msymbol(i i) lwidth(thick thick) lcolor(black gray) lpattern(solid shortdash) /*
*/legend(label(1 "Treated") label(2 "Control") rows(2))

graph save Graph "Logfiles\graphfiles\cdfmarzo3esom1_nonpublic.gph", replace

graph export "Logfiles\graphfiles\cdfmarzo3esom1_nonpublic.eps", as(eps) preview(on) replace

/**************************+ adjusting PRIVATE****************** */


use "Datafiles\temp.dta", replace
drop if publico2==.
gen contesta_fam=(family_P1!=.)
replace family_edumad_sec=0 if family_edumad_sec==.

replace family_edumad_ter=0 if family_edumad_ter==.

replace family_edupad_sec=0 if family_edupad_sec==.

replace family_edupad_ter=0 if family_edupad_ter==.

bys publico2: summ E_dropA repetidores foreign autonomop trabajaempp paradop  /*
*/ autonomom trabajaempm paradom contesta_fam  family_edumad_sec family_edumad_ter family_edupad_sec family_edupad_ter

logit publico2 E_dropA repetidores foreign autonomop trabajaempp paradop  /*
*/ autonomom trabajaempm paradom contesta_fam  family_edumad_sec family_edumad_ter family_edupad_sec family_edupad_ter

predict phat 

* Figure 3

sum publico2 
gen pi=r(mean)
gen W=(publico2*(1)) +((1-publico2)* (((1-pi)*phat)/(pi*(1-phat))))


bys publico2: summ E_dropA repetidores foreign autonomop trabajaempp paradop  /*
*/ autonomom trabajaempm paradom contesta_fam  family_edumad_sec family_edumad_ter family_edupad_sec family_edupad_ter [aw=W]


  * Non Public REWEIGHTED
gen n=_n
gen index=(n/100)
gen cdfT=.
gen cdfC=.
qui compress
local i=1
while `i'<=100 {
	gen d`i'=(postest<=((`i'/100))) 
	sum d`i'
	reg d`i' treated norm_pretest norm_pretestmis stratum_c2-stratum_c16 if publico2==0 [aw=W], cluster(COD_CENTRO)
	replace cdfT=_b[_cons] + _b[treated] if _n==`i'
	replace cdfC=_b[_cons] if _n==`i'
	drop d`i'
	qui compress
local i=`i'+1
}


keep if cdfT!=.
keep n index cdf*
drop if index>10
sort n
sc cdfT cdfC index, c(l l) title("CDF of March scores -non public weighted as public") xtitle("Percentage of correct answers ")  ytitle("Cumulative percentage of the sample") /*
*/ msymbol(i i) lwidth(thick thick) lcolor(black gray) lpattern(solid shortdash) /*
*/legend(label(1 "Treated") label(2 "Control") rows(2))

graph save Graph "Logfiles\graphfiles\cdfmarzo3esom1_non_public_reweighted.gph", replace

graph export "Logfiles\graphfiles\cdfmarzo3esom1_non_public_reweighted.eps", as(eps) preview(on) replace


