clear all
cap log close
set more off
cd "C:\Users\Usuario\Dropbox\JHR\replication file november\Tables\TableW5W6"

log using "TableW6.log", replace

*****************
**** Table W6 ****
*****************

use "C:\Users\Usuario\Dropbox\JHR\replication file\datafiles\Students", clear


** Variables **

* Frequency talks to parents about economics
foreach x in daily0 onceweek0 bonceweek0 nevertalk0 {
replace `x'=0 if `x'==.
}

* Hypothetical saving choices

** H1 (100 today, 120 in three weeks) 
set seed 999
gen u = uniform()

replace dec100_120=0 if december_CA_P11A==3 & u>=0.5
replace dec100_120=1 if december_CA_P11A==3 & u<0.5
label define dec100_120 1 "100 euros today" 0 "120 in three weeks", replace

replace dec100_120_mis=0 if december_CA_P11A==3		//now, dec100_120_mis=1 only when december_CA_P11A==.
replace dec100_120=0 if dec100_120_mis==1
replace dec100_120=. if december_CA_P11A==.

label define mar100_120 1 "100 euros today" 0 "120 in three weeks", replace

** H2 (100 today, 120 in six weeks) (March)
label define mar100_120_2 1 "100 euros today" 0 "120 in six weeks", replace

** H3 (100 today, 150 in three weeks) 
replace dec100_150=0 if december_CA_P11B==3 & u>=0.5
replace dec100_150=1 if december_CA_P11B==3 & u<0.5
label define dec100_150 1 "100 euros today" 0 "150 in three weeks", replace

replace dec100_150_mis=0 if december_CA_P11B==3		//now, dec100_150_mis=1 only when december_CA_P11B==.
replace dec100_150=0 if dec100_150_mis==1
replace dec100_150=. if december_CA_P11B==.

label define mar100_150 1 "100 euros today" 0 "150 in three weeks", replace

** H4 (100 today, 180 in three weeks) 
replace dec100_180=0 if december_CA_P11C==3 & u>=0.5
replace dec100_180=1 if december_CA_P11C==3 & u<0.5
label define dec100_180 1 "100 euros today" 0 "180 in three weeks", replace

replace dec100_180_mis=0 if december_CA_P11C==3		//now, dec100_180_mis=1 only when december_CA_P11C==.
replace dec100_180=0 if dec100_180_mis==1
replace dec100_180=. if december_CA_P11C==.

label define mar100_180 1 "100 euros today" 0 "180 in three weeks", replace
label variable treated 		"Treated"


cd  "C:\Users\Usuario\Dropbox\JHR\replication file"
save "Datafiles\append1.dta",replace

/* TALK TO PARENTS*/

use "Datafiles\append1.dta"
gen AFTER=1

append using "Datafiles\append1.dta"


gen 	LABOR_INSIDE=0
replace LABOR_INSIDE=1 if (paga_tcasa_1==1 | paga_negociof_1==1) & AFTER==1
replace LABOR_INSIDE=1 if (paga_tcasa_0==1 | paga_negociof_0==1) & AFTER==.

gen 	LABOR_OUTSIDE=0
replace LABOR_OUTSIDE=1 if (venta_internet_1==1 | trab_ocas_1==1) & AFTER==1
replace LABOR_OUTSIDE=1 if (venta_internet_0==0 | trab_ocas_0==1) & AFTER==.


gen		FREQ_TALKS=4 if march_CA_C5==1 & AFTER==1
replace FREQ_TALKS=3 if march_CA_C5==2 & AFTER==1
replace FREQ_TALKS=2 if march_CA_C5==3 & AFTER==1
replace FREQ_TALKS=1 if march_CA_C5==4 & AFTER==1

replace FREQ_TALKS=4 if december_CA_P6==1 & AFTER==.
replace FREQ_TALKS=3 if december_CA_P6==2 & AFTER==.
replace FREQ_TALKS=2 if december_CA_P6==3 & AFTER==.
replace FREQ_TALKS=1 if december_CA_P6==4 & AFTER==.



replace AFTER=0 if AFTER==.
gen AFTER_TREAT=treated*AFTER

********************************************* REGRESSIONS: SAVING ATTITUDES ********************************

* TALKS TO PARENTS

reg FREQ_TALKS AFTER_TREAT AFTER treated  stratum_c2-stratum_c16 if curso==3 & balanced_sample==1, robust cluster(COD_CENTRO)
areg FREQ_TALKS AFTER_TREAT AFTER treated  stratum_c2-stratum_c16 if curso==3 & balanced_sample==1, robust cluster(COD_CENTRO) absorb(idestu)

oprobit FREQ_TALKS AFTER_TREAT AFTER treated  stratum_c2-stratum_c16  if curso==3 & balanced_sample==1, robust cluster(COD_CENTRO) 

* INCOME SOURCES

reg LABOR_INSIDE AFTER_TREAT AFTER treated stratum_c2-stratum_c16  if curso==3 & balanced_sample==1, robust cluster(COD_CENTRO)
areg LABOR_INSIDE AFTER_TREAT AFTER treated stratum_c2-stratum_c16  if curso==3 & balanced_sample==1, robust cluster(COD_CENTRO) absorb(idestu)


/*********************************CHOICES ***************************** */
** Pooling Data **

use			 "Datafiles\append1.dta",clear
gen dum1=1
append using "Datafiles\append1.dta"
replace dum1=2 if dum1==.
append using "Datafiles\append1.dta"
replace dum1=3 if dum1==.
*append using "Datafiles\append1.dta"
*replace dum1=4 if dum1==.


*generar las elecciones DICIEMBRE
gen		eleccion_dec= dec100_120 if dum1==1
replace eleccion_dec= dec100_150 if dum1==2
replace eleccion_dec= dec100_180 if dum1==3

*generar las elecciones MARZO
gen		eleccion_mar= mar100_120 	if dum1==1
replace eleccion_mar= mar100_150 	if dum1==2
replace eleccion_mar= mar100_180 	if dum1==3

* Dummies de eleccion
gen dum_rd20	=(dum1==1)
gen dum_rd50	=(dum1==2)
gen dum_rd80	=(dum1==3)

save "Datafiles\appended.dta", replace

cd  "C:\Users\Usuario\Dropbox\JHR\replication file"

** Earlier Choice (Pooled):
use "Datafiles\appended.dta"

gen AFTER=1
append using "Datafiles\appended.dta"

keep if curso==3
keep if balanced_sample==1

gen		CHOICE= eleccion_mar if AFTER==1
replace CHOICE= eleccion_dec if AFTER==.


replace AFTER=0 if AFTER==.
gen TREATED_AFTER=AFTER*treated

reg CHOIC TREATED_AFTER treated AFTER dum_rd50 dum_rd80  stratum_c2-stratum_c16, cluster(COD_CENTRO)

areg CHOIC TREATED_AFTER treated AFTER dum_rd50 dum_rd80  stratum_c2-stratum_c16 , cluster(COD_CENTRO) absorb(idestu)

dprobit CHOIC TREATED_AFTER treated AFTER dum_rd50 dum_rd80  stratum_c2-stratum_c16, cluster(COD_CENTRO)

cap log close

